# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.dashboard_template_variable_preset_value import (
        DashboardTemplateVariablePresetValue,
    )


class DashboardTemplateVariablePreset(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.dashboard_template_variable_preset_value import (
            DashboardTemplateVariablePresetValue,
        )

        return {
            "name": (str,),
            "template_variables": ([DashboardTemplateVariablePresetValue],),
        }

    attribute_map = {
        "name": "name",
        "template_variables": "template_variables",
    }

    def __init__(
        self_,
        name: Union[str, UnsetType] = unset,
        template_variables: Union[List[DashboardTemplateVariablePresetValue], UnsetType] = unset,
        **kwargs,
    ):
        """
        Template variables saved views.

        :param name: The name of the variable.
        :type name: str, optional

        :param template_variables: List of variables.
        :type template_variables: [DashboardTemplateVariablePresetValue], optional
        """
        if name is not unset:
            kwargs["name"] = name
        if template_variables is not unset:
            kwargs["template_variables"] = template_variables
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.ci_app_group_by_histogram import CIAppGroupByHistogram
    from datadog_api_client.v2.model.ci_app_group_by_missing import CIAppGroupByMissing
    from datadog_api_client.v2.model.ci_app_aggregate_sort import CIAppAggregateSort
    from datadog_api_client.v2.model.ci_app_group_by_total import CIAppGroupByTotal


class CIAppTestsGroupBy(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.ci_app_group_by_histogram import CIAppGroupByHistogram
        from datadog_api_client.v2.model.ci_app_group_by_missing import CIAppGroupByMissing
        from datadog_api_client.v2.model.ci_app_aggregate_sort import CIAppAggregateSort
        from datadog_api_client.v2.model.ci_app_group_by_total import CIAppGroupByTotal

        return {
            "facet": (str,),
            "histogram": (CIAppGroupByHistogram,),
            "limit": (int,),
            "missing": (CIAppGroupByMissing,),
            "sort": (CIAppAggregateSort,),
            "total": (CIAppGroupByTotal,),
        }

    attribute_map = {
        "facet": "facet",
        "histogram": "histogram",
        "limit": "limit",
        "missing": "missing",
        "sort": "sort",
        "total": "total",
    }

    def __init__(
        self_,
        facet: str,
        histogram: Union[CIAppGroupByHistogram, UnsetType] = unset,
        limit: Union[int, UnsetType] = unset,
        missing: Union[CIAppGroupByMissing, str, float, UnsetType] = unset,
        sort: Union[CIAppAggregateSort, UnsetType] = unset,
        total: Union[CIAppGroupByTotal, bool, str, float, UnsetType] = unset,
        **kwargs,
    ):
        """
        A group-by rule.

        :param facet: The name of the facet to use (required).
        :type facet: str

        :param histogram: Used to perform a histogram computation (only for measure facets).
            At most, 100 buckets are allowed, the number of buckets is ``(max - min)/interval``.
        :type histogram: CIAppGroupByHistogram, optional

        :param limit: The maximum buckets to return for this group-by.
        :type limit: int, optional

        :param missing: The value to use for logs that don't have the facet used to group-by.
        :type missing: CIAppGroupByMissing, optional

        :param sort: A sort rule.
        :type sort: CIAppAggregateSort, optional

        :param total: A resulting object to put the given computes in over all the matching records.
        :type total: CIAppGroupByTotal, optional
        """
        if histogram is not unset:
            kwargs["histogram"] = histogram
        if limit is not unset:
            kwargs["limit"] = limit
        if missing is not unset:
            kwargs["missing"] = missing
        if sort is not unset:
            kwargs["sort"] = sort
        if total is not unset:
            kwargs["total"] = total
        super().__init__(kwargs)

        self_.facet = facet



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SyntheticsTiming(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "dns": (float,),
            "download": (float,),
            "first_byte": (float,),
            "handshake": (float,),
            "redirect": (float,),
            "ssl": (float,),
            "tcp": (float,),
            "total": (float,),
            "wait": (float,),
        }

    attribute_map = {
        "dns": "dns",
        "download": "download",
        "first_byte": "firstByte",
        "handshake": "handshake",
        "redirect": "redirect",
        "ssl": "ssl",
        "tcp": "tcp",
        "total": "total",
        "wait": "wait",
    }

    def __init__(
        self_,
        dns: Union[float, UnsetType] = unset,
        download: Union[float, UnsetType] = unset,
        first_byte: Union[float, UnsetType] = unset,
        handshake: Union[float, UnsetType] = unset,
        redirect: Union[float, UnsetType] = unset,
        ssl: Union[float, UnsetType] = unset,
        tcp: Union[float, UnsetType] = unset,
        total: Union[float, UnsetType] = unset,
        wait: Union[float, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing all metrics and their values collected for a Synthetic API test.
        Learn more about those metrics in `Synthetics documentation <https://docs.datadoghq.com/synthetics/#metrics>`_.

        :param dns: The duration in millisecond of the DNS lookup.
        :type dns: float, optional

        :param download: The time in millisecond to download the response.
        :type download: float, optional

        :param first_byte: The time in millisecond to first byte.
        :type first_byte: float, optional

        :param handshake: The duration in millisecond of the TLS handshake.
        :type handshake: float, optional

        :param redirect: The time in millisecond spent during redirections.
        :type redirect: float, optional

        :param ssl: The duration in millisecond of the TLS handshake.
        :type ssl: float, optional

        :param tcp: Time in millisecond to establish the TCP connection.
        :type tcp: float, optional

        :param total: The overall time in millisecond the request took to be processed.
        :type total: float, optional

        :param wait: Time spent in millisecond waiting for a response.
        :type wait: float, optional
        """
        if dns is not unset:
            kwargs["dns"] = dns
        if download is not unset:
            kwargs["download"] = download
        if first_byte is not unset:
            kwargs["first_byte"] = first_byte
        if handshake is not unset:
            kwargs["handshake"] = handshake
        if redirect is not unset:
            kwargs["redirect"] = redirect
        if ssl is not unset:
            kwargs["ssl"] = ssl
        if tcp is not unset:
            kwargs["tcp"] = tcp
        if total is not unset:
            kwargs["total"] = total
        if wait is not unset:
            kwargs["wait"] = wait
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
    from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType


class SyntheticsAssertionTarget(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
        from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType

        return {
            "operator": (SyntheticsAssertionOperator,),
            "_property": (str,),
            "target": (
                bool,
                date,
                datetime,
                dict,
                float,
                int,
                list,
                str,
                none_type,
            ),
            "type": (SyntheticsAssertionType,),
        }

    attribute_map = {
        "operator": "operator",
        "_property": "property",
        "target": "target",
        "type": "type",
    }

    def __init__(
        self_,
        operator: SyntheticsAssertionOperator,
        target: Any,
        type: SyntheticsAssertionType,
        _property: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        An assertion which uses a simple target.

        :param operator: Assertion operator to apply.
        :type operator: SyntheticsAssertionOperator

        :param _property: The associated assertion property.
        :type _property: str, optional

        :param target: Value used by the operator.
        :type target: bool, date, datetime, dict, float, int, list, str, none_type

        :param type: Type of the assertion.
        :type type: SyntheticsAssertionType
        """
        if _property is not unset:
            kwargs["_property"] = _property
        super().__init__(kwargs)

        self_.operator = operator
        self_.target = target
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.user_create_data import UserCreateData


class UserCreateRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.user_create_data import UserCreateData

        return {
            "data": (UserCreateData,),
        }

    attribute_map = {
        "data": "data",
    }

    def __init__(self_, data: UserCreateData, **kwargs):
        """
        Create a user.

        :param data: Object to create a user.
        :type data: UserCreateData
        """
        super().__init__(kwargs)

        self_.data = data



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_rule_severity import SecurityMonitoringRuleSeverity


class CloudConfigurationRuleCaseCreate(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_rule_severity import SecurityMonitoringRuleSeverity

        return {
            "notifications": ([str],),
            "status": (SecurityMonitoringRuleSeverity,),
        }

    attribute_map = {
        "notifications": "notifications",
        "status": "status",
    }

    def __init__(
        self_, status: SecurityMonitoringRuleSeverity, notifications: Union[List[str], UnsetType] = unset, **kwargs
    ):
        """
        Description of signals.

        :param notifications: Notification targets for each rule case.
        :type notifications: [str], optional

        :param status: Severity of the Security Signal.
        :type status: SecurityMonitoringRuleSeverity
        """
        if notifications is not unset:
            kwargs["notifications"] = notifications
        super().__init__(kwargs)

        self_.status = status



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_browser_test_result_short import SyntheticsBrowserTestResultShort


class SyntheticsGetBrowserTestLatestResultsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_browser_test_result_short import SyntheticsBrowserTestResultShort

        return {
            "last_timestamp_fetched": (int,),
            "results": ([SyntheticsBrowserTestResultShort],),
        }

    attribute_map = {
        "last_timestamp_fetched": "last_timestamp_fetched",
        "results": "results",
    }

    def __init__(
        self_,
        last_timestamp_fetched: Union[int, UnsetType] = unset,
        results: Union[List[SyntheticsBrowserTestResultShort], UnsetType] = unset,
        **kwargs,
    ):
        """
        Object with the latest Synthetic browser test run.

        :param last_timestamp_fetched: Timestamp of the latest browser test run.
        :type last_timestamp_fetched: int, optional

        :param results: Result of the latest browser test run.
        :type results: [SyntheticsBrowserTestResultShort], optional
        """
        if last_timestamp_fetched is not unset:
            kwargs["last_timestamp_fetched"] = last_timestamp_fetched
        if results is not unset:
            kwargs["results"] = results
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetVizType(ModelSimple):
    """
    Whether to display the Alert Graph as a timeseries or a top list.

    :param value: Must be one of ["timeseries", "toplist"].
    :type value: str
    """

    allowed_values = {
        "timeseries",
        "toplist",
    }
    TIMESERIES: ClassVar["WidgetVizType"]
    TOPLIST: ClassVar["WidgetVizType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetVizType.TIMESERIES = WidgetVizType("timeseries")
WidgetVizType.TOPLIST = WidgetVizType("toplist")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringSignalArchiveReason(ModelSimple):
    """
    Reason a signal is archived.

    :param value: Must be one of ["none", "false_positive", "testing_or_maintenance", "other"].
    :type value: str
    """

    allowed_values = {
        "none",
        "false_positive",
        "testing_or_maintenance",
        "other",
    }
    NONE: ClassVar["SecurityMonitoringSignalArchiveReason"]
    FALSE_POSITIVE: ClassVar["SecurityMonitoringSignalArchiveReason"]
    TESTING_OR_MAINTENANCE: ClassVar["SecurityMonitoringSignalArchiveReason"]
    OTHER: ClassVar["SecurityMonitoringSignalArchiveReason"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SecurityMonitoringSignalArchiveReason.NONE = SecurityMonitoringSignalArchiveReason("none")
SecurityMonitoringSignalArchiveReason.FALSE_POSITIVE = SecurityMonitoringSignalArchiveReason("false_positive")
SecurityMonitoringSignalArchiveReason.TESTING_OR_MAINTENANCE = SecurityMonitoringSignalArchiveReason(
    "testing_or_maintenance"
)
SecurityMonitoringSignalArchiveReason.OTHER = SecurityMonitoringSignalArchiveReason("other")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HostMetrics(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "cpu": (float,),
            "iowait": (float,),
            "load": (float,),
        }

    attribute_map = {
        "cpu": "cpu",
        "iowait": "iowait",
        "load": "load",
    }

    def __init__(
        self_,
        cpu: Union[float, UnsetType] = unset,
        iowait: Union[float, UnsetType] = unset,
        load: Union[float, UnsetType] = unset,
        **kwargs,
    ):
        """
        Host Metrics collected.

        :param cpu: The percent of CPU used (everything but idle).
        :type cpu: float, optional

        :param iowait: The percent of CPU spent waiting on the IO (not reported for all platforms).
        :type iowait: float, optional

        :param load: The system load over the last 15 minutes.
        :type load: float, optional
        """
        if cpu is not unset:
            kwargs["cpu"] = cpu
        if iowait is not unset:
            kwargs["iowait"] = iowait
        if load is not unset:
            kwargs["load"] = load
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slo_response_data import SLOResponseData


class SLOResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slo_response_data import SLOResponseData

        return {
            "data": (SLOResponseData,),
            "errors": ([str],),
        }

    attribute_map = {
        "data": "data",
        "errors": "errors",
    }

    def __init__(
        self_, data: Union[SLOResponseData, UnsetType] = unset, errors: Union[List[str], UnsetType] = unset, **kwargs
    ):
        """
        A service level objective response containing a single service level objective.

        :param data: A service level objective object includes a service level indicator, thresholds
            for one or more timeframes, and metadata ( ``name`` , ``description`` , ``tags`` , etc.).
        :type data: SLOResponseData, optional

        :param errors: An array of error messages. Each endpoint documents how/whether this field is
            used.
        :type errors: [str], optional
        """
        if data is not unset:
            kwargs["data"] = data
        if errors is not unset:
            kwargs["errors"] = errors
        super().__init__(kwargs)



"""
Create an incident returns "CREATED" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incidents_api import IncidentsApi
from datadog_api_client.v2.model.incident_create_attributes import IncidentCreateAttributes
from datadog_api_client.v2.model.incident_create_data import IncidentCreateData
from datadog_api_client.v2.model.incident_create_relationships import IncidentCreateRelationships
from datadog_api_client.v2.model.incident_create_request import IncidentCreateRequest
from datadog_api_client.v2.model.incident_field_attributes_single_value import IncidentFieldAttributesSingleValue
from datadog_api_client.v2.model.incident_field_attributes_single_value_type import (
    IncidentFieldAttributesSingleValueType,
)
from datadog_api_client.v2.model.incident_type import IncidentType
from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser
from datadog_api_client.v2.model.nullable_relationship_to_user_data import NullableRelationshipToUserData
from datadog_api_client.v2.model.users_type import UsersType

# there is a valid "user" in the system
USER_DATA_ID = environ["USER_DATA_ID"]

body = IncidentCreateRequest(
    data=IncidentCreateData(
        type=IncidentType.INCIDENTS,
        attributes=IncidentCreateAttributes(
            title="Example-Create_an_incident_returns_CREATED_response",
            customer_impacted=False,
            fields=dict(
                state=IncidentFieldAttributesSingleValue(
                    type=IncidentFieldAttributesSingleValueType.DROPDOWN,
                    value="resolved",
                ),
            ),
        ),
        relationships=IncidentCreateRelationships(
            commander_user=NullableRelationshipToUser(
                data=NullableRelationshipToUserData(
                    type=UsersType.USERS,
                    id=USER_DATA_ID,
                ),
            ),
        ),
    ),
)

configuration = Configuration()
configuration.unstable_operations["create_incident"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentsApi(api_client)
    response = api_instance.create_incident(body=body)

    print(response)



"""
Create a security filter returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.model.security_filter_create_attributes import SecurityFilterCreateAttributes
from datadog_api_client.v2.model.security_filter_create_data import SecurityFilterCreateData
from datadog_api_client.v2.model.security_filter_create_request import SecurityFilterCreateRequest
from datadog_api_client.v2.model.security_filter_exclusion_filter import SecurityFilterExclusionFilter
from datadog_api_client.v2.model.security_filter_filtered_data_type import SecurityFilterFilteredDataType
from datadog_api_client.v2.model.security_filter_type import SecurityFilterType

body = SecurityFilterCreateRequest(
    data=SecurityFilterCreateData(
        attributes=SecurityFilterCreateAttributes(
            exclusion_filters=[
                SecurityFilterExclusionFilter(
                    name="Exclude staging",
                    query="source:staging",
                ),
            ],
            filtered_data_type=SecurityFilterFilteredDataType.LOGS,
            is_enabled=True,
            name="Example-Create_a_security_filter_returns_OK_response",
            query="service:ExampleCreateasecurityfilterreturnsOKresponse",
        ),
        type=SecurityFilterType.SECURITY_FILTERS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.create_security_filter(body=body)

    print(response)



"""
Cancel a downtime returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.downtimes_api import DowntimesApi

# there is a valid "downtime" in the system
DOWNTIME_ID = environ["DOWNTIME_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DowntimesApi(api_client)
    api_instance.cancel_downtime(
        downtime_id=int(DOWNTIME_ID),
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class NotebookGraphSize(ModelSimple):
    """
    The size of the graph.

    :param value: Must be one of ["xs", "s", "m", "l", "xl"].
    :type value: str
    """

    allowed_values = {
        "xs",
        "s",
        "m",
        "l",
        "xl",
    }
    EXTRA_SMALL: ClassVar["NotebookGraphSize"]
    SMALL: ClassVar["NotebookGraphSize"]
    MEDIUM: ClassVar["NotebookGraphSize"]
    LARGE: ClassVar["NotebookGraphSize"]
    EXTRA_LARGE: ClassVar["NotebookGraphSize"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


NotebookGraphSize.EXTRA_SMALL = NotebookGraphSize("xs")
NotebookGraphSize.SMALL = NotebookGraphSize("s")
NotebookGraphSize.MEDIUM = NotebookGraphSize("m")
NotebookGraphSize.LARGE = NotebookGraphSize("l")
NotebookGraphSize.EXTRA_LARGE = NotebookGraphSize("xl")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_sort import WidgetSort


class WidgetFieldSort(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_sort import WidgetSort

        return {
            "column": (str,),
            "order": (WidgetSort,),
        }

    attribute_map = {
        "column": "column",
        "order": "order",
    }

    def __init__(self_, column: str, order: WidgetSort, **kwargs):
        """
        Which column and order to sort by

        :param column: Facet path for the column
        :type column: str

        :param order: Widget sorting methods.
        :type order: WidgetSort
        """
        super().__init__(kwargs)

        self_.column = column
        self_.order = order



from datadog_api_client.v2.model.api_error_response import APIErrorResponse
from datadog_api_client.v2.model.api_key_create_attributes import APIKeyCreateAttributes
from datadog_api_client.v2.model.api_key_create_data import APIKeyCreateData
from datadog_api_client.v2.model.api_key_create_request import APIKeyCreateRequest
from datadog_api_client.v2.model.api_key_relationships import APIKeyRelationships
from datadog_api_client.v2.model.api_key_response import APIKeyResponse
from datadog_api_client.v2.model.api_key_response_included_item import APIKeyResponseIncludedItem
from datadog_api_client.v2.model.api_key_update_attributes import APIKeyUpdateAttributes
from datadog_api_client.v2.model.api_key_update_data import APIKeyUpdateData
from datadog_api_client.v2.model.api_key_update_request import APIKeyUpdateRequest
from datadog_api_client.v2.model.api_keys_response import APIKeysResponse
from datadog_api_client.v2.model.api_keys_sort import APIKeysSort
from datadog_api_client.v2.model.api_keys_type import APIKeysType
from datadog_api_client.v2.model.application_key_create_attributes import ApplicationKeyCreateAttributes
from datadog_api_client.v2.model.application_key_create_data import ApplicationKeyCreateData
from datadog_api_client.v2.model.application_key_create_request import ApplicationKeyCreateRequest
from datadog_api_client.v2.model.application_key_relationships import ApplicationKeyRelationships
from datadog_api_client.v2.model.application_key_response import ApplicationKeyResponse
from datadog_api_client.v2.model.application_key_response_included_item import ApplicationKeyResponseIncludedItem
from datadog_api_client.v2.model.application_key_update_attributes import ApplicationKeyUpdateAttributes
from datadog_api_client.v2.model.application_key_update_data import ApplicationKeyUpdateData
from datadog_api_client.v2.model.application_key_update_request import ApplicationKeyUpdateRequest
from datadog_api_client.v2.model.application_keys_sort import ApplicationKeysSort
from datadog_api_client.v2.model.application_keys_type import ApplicationKeysType
from datadog_api_client.v2.model.audit_logs_event import AuditLogsEvent
from datadog_api_client.v2.model.audit_logs_event_attributes import AuditLogsEventAttributes
from datadog_api_client.v2.model.audit_logs_event_type import AuditLogsEventType
from datadog_api_client.v2.model.audit_logs_events_response import AuditLogsEventsResponse
from datadog_api_client.v2.model.audit_logs_query_filter import AuditLogsQueryFilter
from datadog_api_client.v2.model.audit_logs_query_options import AuditLogsQueryOptions
from datadog_api_client.v2.model.audit_logs_query_page_options import AuditLogsQueryPageOptions
from datadog_api_client.v2.model.audit_logs_response_links import AuditLogsResponseLinks
from datadog_api_client.v2.model.audit_logs_response_metadata import AuditLogsResponseMetadata
from datadog_api_client.v2.model.audit_logs_response_page import AuditLogsResponsePage
from datadog_api_client.v2.model.audit_logs_response_status import AuditLogsResponseStatus
from datadog_api_client.v2.model.audit_logs_search_events_request import AuditLogsSearchEventsRequest
from datadog_api_client.v2.model.audit_logs_sort import AuditLogsSort
from datadog_api_client.v2.model.audit_logs_warning import AuditLogsWarning
from datadog_api_client.v2.model.authn_mapping import AuthNMapping
from datadog_api_client.v2.model.authn_mapping_attributes import AuthNMappingAttributes
from datadog_api_client.v2.model.authn_mapping_create_attributes import AuthNMappingCreateAttributes
from datadog_api_client.v2.model.authn_mapping_create_data import AuthNMappingCreateData
from datadog_api_client.v2.model.authn_mapping_create_relationships import AuthNMappingCreateRelationships
from datadog_api_client.v2.model.authn_mapping_create_request import AuthNMappingCreateRequest
from datadog_api_client.v2.model.authn_mapping_included import AuthNMappingIncluded
from datadog_api_client.v2.model.authn_mapping_relationships import AuthNMappingRelationships
from datadog_api_client.v2.model.authn_mapping_response import AuthNMappingResponse
from datadog_api_client.v2.model.authn_mapping_update_attributes import AuthNMappingUpdateAttributes
from datadog_api_client.v2.model.authn_mapping_update_data import AuthNMappingUpdateData
from datadog_api_client.v2.model.authn_mapping_update_relationships import AuthNMappingUpdateRelationships
from datadog_api_client.v2.model.authn_mapping_update_request import AuthNMappingUpdateRequest
from datadog_api_client.v2.model.authn_mappings_response import AuthNMappingsResponse
from datadog_api_client.v2.model.authn_mappings_sort import AuthNMappingsSort
from datadog_api_client.v2.model.authn_mappings_type import AuthNMappingsType
from datadog_api_client.v2.model.ci_app_aggregate_bucket_value import CIAppAggregateBucketValue
from datadog_api_client.v2.model.ci_app_aggregate_bucket_value_timeseries import CIAppAggregateBucketValueTimeseries
from datadog_api_client.v2.model.ci_app_aggregate_bucket_value_timeseries_point import (
    CIAppAggregateBucketValueTimeseriesPoint,
)
from datadog_api_client.v2.model.ci_app_aggregate_sort import CIAppAggregateSort
from datadog_api_client.v2.model.ci_app_aggregate_sort_type import CIAppAggregateSortType
from datadog_api_client.v2.model.ci_app_aggregation_function import CIAppAggregationFunction
from datadog_api_client.v2.model.ci_app_compute import CIAppCompute
from datadog_api_client.v2.model.ci_app_compute_type import CIAppComputeType
from datadog_api_client.v2.model.ci_app_computes import CIAppComputes
from datadog_api_client.v2.model.ci_app_event_attributes import CIAppEventAttributes
from datadog_api_client.v2.model.ci_app_group_by_histogram import CIAppGroupByHistogram
from datadog_api_client.v2.model.ci_app_group_by_missing import CIAppGroupByMissing
from datadog_api_client.v2.model.ci_app_group_by_total import CIAppGroupByTotal
from datadog_api_client.v2.model.ci_app_pipeline_event import CIAppPipelineEvent
from datadog_api_client.v2.model.ci_app_pipeline_event_type_name import CIAppPipelineEventTypeName
from datadog_api_client.v2.model.ci_app_pipeline_events_request import CIAppPipelineEventsRequest
from datadog_api_client.v2.model.ci_app_pipeline_events_response import CIAppPipelineEventsResponse
from datadog_api_client.v2.model.ci_app_pipelines_aggregate_request import CIAppPipelinesAggregateRequest
from datadog_api_client.v2.model.ci_app_pipelines_aggregation_buckets_response import (
    CIAppPipelinesAggregationBucketsResponse,
)
from datadog_api_client.v2.model.ci_app_pipelines_analytics_aggregate_response import (
    CIAppPipelinesAnalyticsAggregateResponse,
)
from datadog_api_client.v2.model.ci_app_pipelines_bucket_response import CIAppPipelinesBucketResponse
from datadog_api_client.v2.model.ci_app_pipelines_group_by import CIAppPipelinesGroupBy
from datadog_api_client.v2.model.ci_app_pipelines_query_filter import CIAppPipelinesQueryFilter
from datadog_api_client.v2.model.ci_app_query_options import CIAppQueryOptions
from datadog_api_client.v2.model.ci_app_query_page_options import CIAppQueryPageOptions
from datadog_api_client.v2.model.ci_app_response_links import CIAppResponseLinks
from datadog_api_client.v2.model.ci_app_response_metadata import CIAppResponseMetadata
from datadog_api_client.v2.model.ci_app_response_page import CIAppResponsePage
from datadog_api_client.v2.model.ci_app_response_status import CIAppResponseStatus
from datadog_api_client.v2.model.ci_app_sort import CIAppSort
from datadog_api_client.v2.model.ci_app_sort_order import CIAppSortOrder
from datadog_api_client.v2.model.ci_app_test_event import CIAppTestEvent
from datadog_api_client.v2.model.ci_app_test_event_type_name import CIAppTestEventTypeName
from datadog_api_client.v2.model.ci_app_test_events_request import CIAppTestEventsRequest
from datadog_api_client.v2.model.ci_app_test_events_response import CIAppTestEventsResponse
from datadog_api_client.v2.model.ci_app_tests_aggregate_request import CIAppTestsAggregateRequest
from datadog_api_client.v2.model.ci_app_tests_aggregation_buckets_response import CIAppTestsAggregationBucketsResponse
from datadog_api_client.v2.model.ci_app_tests_analytics_aggregate_response import CIAppTestsAnalyticsAggregateResponse
from datadog_api_client.v2.model.ci_app_tests_bucket_response import CIAppTestsBucketResponse
from datadog_api_client.v2.model.ci_app_tests_group_by import CIAppTestsGroupBy
from datadog_api_client.v2.model.ci_app_tests_query_filter import CIAppTestsQueryFilter
from datadog_api_client.v2.model.ci_app_warning import CIAppWarning
from datadog_api_client.v2.model.chargeback_breakdown import ChargebackBreakdown
from datadog_api_client.v2.model.cloud_configuration_compliance_rule_options import (
    CloudConfigurationComplianceRuleOptions,
)
from datadog_api_client.v2.model.cloud_configuration_rego_rule import CloudConfigurationRegoRule
from datadog_api_client.v2.model.cloud_configuration_rule_case_create import CloudConfigurationRuleCaseCreate
from datadog_api_client.v2.model.cloud_configuration_rule_compliance_signal_options import (
    CloudConfigurationRuleComplianceSignalOptions,
)
from datadog_api_client.v2.model.cloud_configuration_rule_create_payload import CloudConfigurationRuleCreatePayload
from datadog_api_client.v2.model.cloud_configuration_rule_options import CloudConfigurationRuleOptions
from datadog_api_client.v2.model.cloud_configuration_rule_type import CloudConfigurationRuleType
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_attributes import (
    CloudWorkloadSecurityAgentRuleAttributes,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_attributes import (
    CloudWorkloadSecurityAgentRuleCreateAttributes,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_data import (
    CloudWorkloadSecurityAgentRuleCreateData,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_create_request import (
    CloudWorkloadSecurityAgentRuleCreateRequest,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_creator_attributes import (
    CloudWorkloadSecurityAgentRuleCreatorAttributes,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_data import CloudWorkloadSecurityAgentRuleData
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_response import (
    CloudWorkloadSecurityAgentRuleResponse,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_type import CloudWorkloadSecurityAgentRuleType
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_attributes import (
    CloudWorkloadSecurityAgentRuleUpdateAttributes,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_data import (
    CloudWorkloadSecurityAgentRuleUpdateData,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_request import (
    CloudWorkloadSecurityAgentRuleUpdateRequest,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_updater_attributes import (
    CloudWorkloadSecurityAgentRuleUpdaterAttributes,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rules_list_response import (
    CloudWorkloadSecurityAgentRulesListResponse,
)
from datadog_api_client.v2.model.confluent_account_create_request import ConfluentAccountCreateRequest
from datadog_api_client.v2.model.confluent_account_create_request_attributes import (
    ConfluentAccountCreateRequestAttributes,
)
from datadog_api_client.v2.model.confluent_account_create_request_data import ConfluentAccountCreateRequestData
from datadog_api_client.v2.model.confluent_account_resource_attributes import ConfluentAccountResourceAttributes
from datadog_api_client.v2.model.confluent_account_response import ConfluentAccountResponse
from datadog_api_client.v2.model.confluent_account_response_attributes import ConfluentAccountResponseAttributes
from datadog_api_client.v2.model.confluent_account_response_data import ConfluentAccountResponseData
from datadog_api_client.v2.model.confluent_account_type import ConfluentAccountType
from datadog_api_client.v2.model.confluent_account_update_request import ConfluentAccountUpdateRequest
from datadog_api_client.v2.model.confluent_account_update_request_attributes import (
    ConfluentAccountUpdateRequestAttributes,
)
from datadog_api_client.v2.model.confluent_account_update_request_data import ConfluentAccountUpdateRequestData
from datadog_api_client.v2.model.confluent_accounts_response import ConfluentAccountsResponse
from datadog_api_client.v2.model.confluent_resource_request import ConfluentResourceRequest
from datadog_api_client.v2.model.confluent_resource_request_attributes import ConfluentResourceRequestAttributes
from datadog_api_client.v2.model.confluent_resource_request_data import ConfluentResourceRequestData
from datadog_api_client.v2.model.confluent_resource_response import ConfluentResourceResponse
from datadog_api_client.v2.model.confluent_resource_response_attributes import ConfluentResourceResponseAttributes
from datadog_api_client.v2.model.confluent_resource_response_data import ConfluentResourceResponseData
from datadog_api_client.v2.model.confluent_resource_type import ConfluentResourceType
from datadog_api_client.v2.model.confluent_resources_response import ConfluentResourcesResponse
from datadog_api_client.v2.model.content_encoding import ContentEncoding
from datadog_api_client.v2.model.cost_by_org import CostByOrg
from datadog_api_client.v2.model.cost_by_org_attributes import CostByOrgAttributes
from datadog_api_client.v2.model.cost_by_org_response import CostByOrgResponse
from datadog_api_client.v2.model.cost_by_org_type import CostByOrgType
from datadog_api_client.v2.model.creator import Creator
from datadog_api_client.v2.model.dashboard_list_add_items_request import DashboardListAddItemsRequest
from datadog_api_client.v2.model.dashboard_list_add_items_response import DashboardListAddItemsResponse
from datadog_api_client.v2.model.dashboard_list_delete_items_request import DashboardListDeleteItemsRequest
from datadog_api_client.v2.model.dashboard_list_delete_items_response import DashboardListDeleteItemsResponse
from datadog_api_client.v2.model.dashboard_list_item import DashboardListItem
from datadog_api_client.v2.model.dashboard_list_item_request import DashboardListItemRequest
from datadog_api_client.v2.model.dashboard_list_item_response import DashboardListItemResponse
from datadog_api_client.v2.model.dashboard_list_items import DashboardListItems
from datadog_api_client.v2.model.dashboard_list_update_items_request import DashboardListUpdateItemsRequest
from datadog_api_client.v2.model.dashboard_list_update_items_response import DashboardListUpdateItemsResponse
from datadog_api_client.v2.model.dashboard_type import DashboardType
from datadog_api_client.v2.model.event import Event
from datadog_api_client.v2.model.event_attributes import EventAttributes
from datadog_api_client.v2.model.event_priority import EventPriority
from datadog_api_client.v2.model.event_response import EventResponse
from datadog_api_client.v2.model.event_response_attributes import EventResponseAttributes
from datadog_api_client.v2.model.event_status_type import EventStatusType
from datadog_api_client.v2.model.event_type import EventType
from datadog_api_client.v2.model.events_aggregation import EventsAggregation
from datadog_api_client.v2.model.events_compute import EventsCompute
from datadog_api_client.v2.model.events_data_source import EventsDataSource
from datadog_api_client.v2.model.events_group_by import EventsGroupBy
from datadog_api_client.v2.model.events_group_by_sort import EventsGroupBySort
from datadog_api_client.v2.model.events_list_request import EventsListRequest
from datadog_api_client.v2.model.events_list_response import EventsListResponse
from datadog_api_client.v2.model.events_list_response_links import EventsListResponseLinks
from datadog_api_client.v2.model.events_query_filter import EventsQueryFilter
from datadog_api_client.v2.model.events_query_group_bys import EventsQueryGroupBys
from datadog_api_client.v2.model.events_query_options import EventsQueryOptions
from datadog_api_client.v2.model.events_request_page import EventsRequestPage
from datadog_api_client.v2.model.events_response_metadata import EventsResponseMetadata
from datadog_api_client.v2.model.events_response_metadata_page import EventsResponseMetadataPage
from datadog_api_client.v2.model.events_scalar_query import EventsScalarQuery
from datadog_api_client.v2.model.events_search import EventsSearch
from datadog_api_client.v2.model.events_sort import EventsSort
from datadog_api_client.v2.model.events_sort_type import EventsSortType
from datadog_api_client.v2.model.events_timeseries_query import EventsTimeseriesQuery
from datadog_api_client.v2.model.events_warning import EventsWarning
from datadog_api_client.v2.model.formula_limit import FormulaLimit
from datadog_api_client.v2.model.full_api_key import FullAPIKey
from datadog_api_client.v2.model.full_api_key_attributes import FullAPIKeyAttributes
from datadog_api_client.v2.model.full_application_key import FullApplicationKey
from datadog_api_client.v2.model.full_application_key_attributes import FullApplicationKeyAttributes
from datadog_api_client.v2.model.group_tags import GroupTags
from datadog_api_client.v2.model.http_log import HTTPLog
from datadog_api_client.v2.model.http_log_error import HTTPLogError
from datadog_api_client.v2.model.http_log_errors import HTTPLogErrors
from datadog_api_client.v2.model.http_log_item import HTTPLogItem
from datadog_api_client.v2.model.hourly_usage import HourlyUsage
from datadog_api_client.v2.model.hourly_usage_attributes import HourlyUsageAttributes
from datadog_api_client.v2.model.hourly_usage_measurement import HourlyUsageMeasurement
from datadog_api_client.v2.model.hourly_usage_metadata import HourlyUsageMetadata
from datadog_api_client.v2.model.hourly_usage_pagination import HourlyUsagePagination
from datadog_api_client.v2.model.hourly_usage_response import HourlyUsageResponse
from datadog_api_client.v2.model.hourly_usage_type import HourlyUsageType
from datadog_api_client.v2.model.idp_metadata_form_data import IdPMetadataFormData
from datadog_api_client.v2.model.incident_attachment_attachment_type import IncidentAttachmentAttachmentType
from datadog_api_client.v2.model.incident_attachment_attributes import IncidentAttachmentAttributes
from datadog_api_client.v2.model.incident_attachment_data import IncidentAttachmentData
from datadog_api_client.v2.model.incident_attachment_link_attachment_type import IncidentAttachmentLinkAttachmentType
from datadog_api_client.v2.model.incident_attachment_link_attributes import IncidentAttachmentLinkAttributes
from datadog_api_client.v2.model.incident_attachment_link_attributes_attachment_object import (
    IncidentAttachmentLinkAttributesAttachmentObject,
)
from datadog_api_client.v2.model.incident_attachment_postmortem_attachment_type import (
    IncidentAttachmentPostmortemAttachmentType,
)
from datadog_api_client.v2.model.incident_attachment_postmortem_attributes import IncidentAttachmentPostmortemAttributes
from datadog_api_client.v2.model.incident_attachment_related_object import IncidentAttachmentRelatedObject
from datadog_api_client.v2.model.incident_attachment_relationships import IncidentAttachmentRelationships
from datadog_api_client.v2.model.incident_attachment_type import IncidentAttachmentType
from datadog_api_client.v2.model.incident_attachment_update_attributes import IncidentAttachmentUpdateAttributes
from datadog_api_client.v2.model.incident_attachment_update_data import IncidentAttachmentUpdateData
from datadog_api_client.v2.model.incident_attachment_update_request import IncidentAttachmentUpdateRequest
from datadog_api_client.v2.model.incident_attachment_update_response import IncidentAttachmentUpdateResponse
from datadog_api_client.v2.model.incident_attachments_postmortem_attributes_attachment_object import (
    IncidentAttachmentsPostmortemAttributesAttachmentObject,
)
from datadog_api_client.v2.model.incident_attachments_response import IncidentAttachmentsResponse
from datadog_api_client.v2.model.incident_attachments_response_included_item import (
    IncidentAttachmentsResponseIncludedItem,
)
from datadog_api_client.v2.model.incident_create_attributes import IncidentCreateAttributes
from datadog_api_client.v2.model.incident_create_data import IncidentCreateData
from datadog_api_client.v2.model.incident_create_relationships import IncidentCreateRelationships
from datadog_api_client.v2.model.incident_create_request import IncidentCreateRequest
from datadog_api_client.v2.model.incident_field_attributes import IncidentFieldAttributes
from datadog_api_client.v2.model.incident_field_attributes_multiple_value import IncidentFieldAttributesMultipleValue
from datadog_api_client.v2.model.incident_field_attributes_single_value import IncidentFieldAttributesSingleValue
from datadog_api_client.v2.model.incident_field_attributes_single_value_type import (
    IncidentFieldAttributesSingleValueType,
)
from datadog_api_client.v2.model.incident_field_attributes_value_type import IncidentFieldAttributesValueType
from datadog_api_client.v2.model.incident_integration_metadata_type import IncidentIntegrationMetadataType
from datadog_api_client.v2.model.incident_notification_handle import IncidentNotificationHandle
from datadog_api_client.v2.model.incident_postmortem_type import IncidentPostmortemType
from datadog_api_client.v2.model.incident_related_object import IncidentRelatedObject
from datadog_api_client.v2.model.incident_response import IncidentResponse
from datadog_api_client.v2.model.incident_response_attributes import IncidentResponseAttributes
from datadog_api_client.v2.model.incident_response_data import IncidentResponseData
from datadog_api_client.v2.model.incident_response_included_item import IncidentResponseIncludedItem
from datadog_api_client.v2.model.incident_response_meta import IncidentResponseMeta
from datadog_api_client.v2.model.incident_response_meta_pagination import IncidentResponseMetaPagination
from datadog_api_client.v2.model.incident_response_relationships import IncidentResponseRelationships
from datadog_api_client.v2.model.incident_service_create_attributes import IncidentServiceCreateAttributes
from datadog_api_client.v2.model.incident_service_create_data import IncidentServiceCreateData
from datadog_api_client.v2.model.incident_service_create_request import IncidentServiceCreateRequest
from datadog_api_client.v2.model.incident_service_included_items import IncidentServiceIncludedItems
from datadog_api_client.v2.model.incident_service_relationships import IncidentServiceRelationships
from datadog_api_client.v2.model.incident_service_response import IncidentServiceResponse
from datadog_api_client.v2.model.incident_service_response_attributes import IncidentServiceResponseAttributes
from datadog_api_client.v2.model.incident_service_response_data import IncidentServiceResponseData
from datadog_api_client.v2.model.incident_service_type import IncidentServiceType
from datadog_api_client.v2.model.incident_service_update_attributes import IncidentServiceUpdateAttributes
from datadog_api_client.v2.model.incident_service_update_data import IncidentServiceUpdateData
from datadog_api_client.v2.model.incident_service_update_request import IncidentServiceUpdateRequest
from datadog_api_client.v2.model.incident_services_response import IncidentServicesResponse
from datadog_api_client.v2.model.incident_team_create_attributes import IncidentTeamCreateAttributes
from datadog_api_client.v2.model.incident_team_create_data import IncidentTeamCreateData
from datadog_api_client.v2.model.incident_team_create_request import IncidentTeamCreateRequest
from datadog_api_client.v2.model.incident_team_included_items import IncidentTeamIncludedItems
from datadog_api_client.v2.model.incident_team_relationships import IncidentTeamRelationships
from datadog_api_client.v2.model.incident_team_response import IncidentTeamResponse
from datadog_api_client.v2.model.incident_team_response_attributes import IncidentTeamResponseAttributes
from datadog_api_client.v2.model.incident_team_response_data import IncidentTeamResponseData
from datadog_api_client.v2.model.incident_team_type import IncidentTeamType
from datadog_api_client.v2.model.incident_team_update_attributes import IncidentTeamUpdateAttributes
from datadog_api_client.v2.model.incident_team_update_data import IncidentTeamUpdateData
from datadog_api_client.v2.model.incident_team_update_request import IncidentTeamUpdateRequest
from datadog_api_client.v2.model.incident_teams_response import IncidentTeamsResponse
from datadog_api_client.v2.model.incident_timeline_cell_create_attributes import IncidentTimelineCellCreateAttributes
from datadog_api_client.v2.model.incident_timeline_cell_markdown_content_type import (
    IncidentTimelineCellMarkdownContentType,
)
from datadog_api_client.v2.model.incident_timeline_cell_markdown_create_attributes import (
    IncidentTimelineCellMarkdownCreateAttributes,
)
from datadog_api_client.v2.model.incident_timeline_cell_markdown_create_attributes_content import (
    IncidentTimelineCellMarkdownCreateAttributesContent,
)
from datadog_api_client.v2.model.incident_type import IncidentType
from datadog_api_client.v2.model.incident_update_attributes import IncidentUpdateAttributes
from datadog_api_client.v2.model.incident_update_data import IncidentUpdateData
from datadog_api_client.v2.model.incident_update_relationships import IncidentUpdateRelationships
from datadog_api_client.v2.model.incident_update_request import IncidentUpdateRequest
from datadog_api_client.v2.model.incidents_response import IncidentsResponse
from datadog_api_client.v2.model.intake_payload_accepted import IntakePayloadAccepted
from datadog_api_client.v2.model.list_application_keys_response import ListApplicationKeysResponse
from datadog_api_client.v2.model.log import Log
from datadog_api_client.v2.model.log_attributes import LogAttributes
from datadog_api_client.v2.model.log_type import LogType
from datadog_api_client.v2.model.logs_aggregate_bucket import LogsAggregateBucket
from datadog_api_client.v2.model.logs_aggregate_bucket_value import LogsAggregateBucketValue
from datadog_api_client.v2.model.logs_aggregate_bucket_value_timeseries import LogsAggregateBucketValueTimeseries
from datadog_api_client.v2.model.logs_aggregate_bucket_value_timeseries_point import (
    LogsAggregateBucketValueTimeseriesPoint,
)
from datadog_api_client.v2.model.logs_aggregate_request import LogsAggregateRequest
from datadog_api_client.v2.model.logs_aggregate_request_page import LogsAggregateRequestPage
from datadog_api_client.v2.model.logs_aggregate_response import LogsAggregateResponse
from datadog_api_client.v2.model.logs_aggregate_response_data import LogsAggregateResponseData
from datadog_api_client.v2.model.logs_aggregate_response_status import LogsAggregateResponseStatus
from datadog_api_client.v2.model.logs_aggregate_sort import LogsAggregateSort
from datadog_api_client.v2.model.logs_aggregate_sort_type import LogsAggregateSortType
from datadog_api_client.v2.model.logs_aggregation_function import LogsAggregationFunction
from datadog_api_client.v2.model.logs_archive import LogsArchive
from datadog_api_client.v2.model.logs_archive_attributes import LogsArchiveAttributes
from datadog_api_client.v2.model.logs_archive_create_request import LogsArchiveCreateRequest
from datadog_api_client.v2.model.logs_archive_create_request_attributes import LogsArchiveCreateRequestAttributes
from datadog_api_client.v2.model.logs_archive_create_request_definition import LogsArchiveCreateRequestDefinition
from datadog_api_client.v2.model.logs_archive_create_request_destination import LogsArchiveCreateRequestDestination
from datadog_api_client.v2.model.logs_archive_definition import LogsArchiveDefinition
from datadog_api_client.v2.model.logs_archive_destination import LogsArchiveDestination
from datadog_api_client.v2.model.logs_archive_destination_azure import LogsArchiveDestinationAzure
from datadog_api_client.v2.model.logs_archive_destination_azure_type import LogsArchiveDestinationAzureType
from datadog_api_client.v2.model.logs_archive_destination_gcs import LogsArchiveDestinationGCS
from datadog_api_client.v2.model.logs_archive_destination_gcs_type import LogsArchiveDestinationGCSType
from datadog_api_client.v2.model.logs_archive_destination_s3 import LogsArchiveDestinationS3
from datadog_api_client.v2.model.logs_archive_destination_s3_type import LogsArchiveDestinationS3Type
from datadog_api_client.v2.model.logs_archive_integration_azure import LogsArchiveIntegrationAzure
from datadog_api_client.v2.model.logs_archive_integration_gcs import LogsArchiveIntegrationGCS
from datadog_api_client.v2.model.logs_archive_integration_s3 import LogsArchiveIntegrationS3
from datadog_api_client.v2.model.logs_archive_order import LogsArchiveOrder
from datadog_api_client.v2.model.logs_archive_order_attributes import LogsArchiveOrderAttributes
from datadog_api_client.v2.model.logs_archive_order_definition import LogsArchiveOrderDefinition
from datadog_api_client.v2.model.logs_archive_order_definition_type import LogsArchiveOrderDefinitionType
from datadog_api_client.v2.model.logs_archive_state import LogsArchiveState
from datadog_api_client.v2.model.logs_archives import LogsArchives
from datadog_api_client.v2.model.logs_compute import LogsCompute
from datadog_api_client.v2.model.logs_compute_type import LogsComputeType
from datadog_api_client.v2.model.logs_group_by import LogsGroupBy
from datadog_api_client.v2.model.logs_group_by_histogram import LogsGroupByHistogram
from datadog_api_client.v2.model.logs_group_by_missing import LogsGroupByMissing
from datadog_api_client.v2.model.logs_group_by_total import LogsGroupByTotal
from datadog_api_client.v2.model.logs_list_request import LogsListRequest
from datadog_api_client.v2.model.logs_list_request_page import LogsListRequestPage
from datadog_api_client.v2.model.logs_list_response import LogsListResponse
from datadog_api_client.v2.model.logs_list_response_links import LogsListResponseLinks
from datadog_api_client.v2.model.logs_metric_compute import LogsMetricCompute
from datadog_api_client.v2.model.logs_metric_compute_aggregation_type import LogsMetricComputeAggregationType
from datadog_api_client.v2.model.logs_metric_create_attributes import LogsMetricCreateAttributes
from datadog_api_client.v2.model.logs_metric_create_data import LogsMetricCreateData
from datadog_api_client.v2.model.logs_metric_create_request import LogsMetricCreateRequest
from datadog_api_client.v2.model.logs_metric_filter import LogsMetricFilter
from datadog_api_client.v2.model.logs_metric_group_by import LogsMetricGroupBy
from datadog_api_client.v2.model.logs_metric_response import LogsMetricResponse
from datadog_api_client.v2.model.logs_metric_response_attributes import LogsMetricResponseAttributes
from datadog_api_client.v2.model.logs_metric_response_compute import LogsMetricResponseCompute
from datadog_api_client.v2.model.logs_metric_response_compute_aggregation_type import (
    LogsMetricResponseComputeAggregationType,
)
from datadog_api_client.v2.model.logs_metric_response_data import LogsMetricResponseData
from datadog_api_client.v2.model.logs_metric_response_filter import LogsMetricResponseFilter
from datadog_api_client.v2.model.logs_metric_response_group_by import LogsMetricResponseGroupBy
from datadog_api_client.v2.model.logs_metric_type import LogsMetricType
from datadog_api_client.v2.model.logs_metric_update_attributes import LogsMetricUpdateAttributes
from datadog_api_client.v2.model.logs_metric_update_compute import LogsMetricUpdateCompute
from datadog_api_client.v2.model.logs_metric_update_data import LogsMetricUpdateData
from datadog_api_client.v2.model.logs_metric_update_request import LogsMetricUpdateRequest
from datadog_api_client.v2.model.logs_metrics_response import LogsMetricsResponse
from datadog_api_client.v2.model.logs_query_filter import LogsQueryFilter
from datadog_api_client.v2.model.logs_query_options import LogsQueryOptions
from datadog_api_client.v2.model.logs_response_metadata import LogsResponseMetadata
from datadog_api_client.v2.model.logs_response_metadata_page import LogsResponseMetadataPage
from datadog_api_client.v2.model.logs_sort import LogsSort
from datadog_api_client.v2.model.logs_sort_order import LogsSortOrder
from datadog_api_client.v2.model.logs_storage_tier import LogsStorageTier
from datadog_api_client.v2.model.logs_warning import LogsWarning
from datadog_api_client.v2.model.metric import Metric
from datadog_api_client.v2.model.metric_active_configuration_type import MetricActiveConfigurationType
from datadog_api_client.v2.model.metric_all_tags import MetricAllTags
from datadog_api_client.v2.model.metric_all_tags_attributes import MetricAllTagsAttributes
from datadog_api_client.v2.model.metric_all_tags_response import MetricAllTagsResponse
from datadog_api_client.v2.model.metric_bulk_configure_tags_type import MetricBulkConfigureTagsType
from datadog_api_client.v2.model.metric_bulk_tag_config_create import MetricBulkTagConfigCreate
from datadog_api_client.v2.model.metric_bulk_tag_config_create_attributes import MetricBulkTagConfigCreateAttributes
from datadog_api_client.v2.model.metric_bulk_tag_config_create_request import MetricBulkTagConfigCreateRequest
from datadog_api_client.v2.model.metric_bulk_tag_config_delete import MetricBulkTagConfigDelete
from datadog_api_client.v2.model.metric_bulk_tag_config_delete_attributes import MetricBulkTagConfigDeleteAttributes
from datadog_api_client.v2.model.metric_bulk_tag_config_delete_request import MetricBulkTagConfigDeleteRequest
from datadog_api_client.v2.model.metric_bulk_tag_config_email_list import MetricBulkTagConfigEmailList
from datadog_api_client.v2.model.metric_bulk_tag_config_response import MetricBulkTagConfigResponse
from datadog_api_client.v2.model.metric_bulk_tag_config_status import MetricBulkTagConfigStatus
from datadog_api_client.v2.model.metric_bulk_tag_config_status_attributes import MetricBulkTagConfigStatusAttributes
from datadog_api_client.v2.model.metric_bulk_tag_config_tag_name_list import MetricBulkTagConfigTagNameList
from datadog_api_client.v2.model.metric_content_encoding import MetricContentEncoding
from datadog_api_client.v2.model.metric_custom_aggregation import MetricCustomAggregation
from datadog_api_client.v2.model.metric_custom_aggregations import MetricCustomAggregations
from datadog_api_client.v2.model.metric_custom_space_aggregation import MetricCustomSpaceAggregation
from datadog_api_client.v2.model.metric_custom_time_aggregation import MetricCustomTimeAggregation
from datadog_api_client.v2.model.metric_distinct_volume import MetricDistinctVolume
from datadog_api_client.v2.model.metric_distinct_volume_attributes import MetricDistinctVolumeAttributes
from datadog_api_client.v2.model.metric_distinct_volume_type import MetricDistinctVolumeType
from datadog_api_client.v2.model.metric_estimate import MetricEstimate
from datadog_api_client.v2.model.metric_estimate_attributes import MetricEstimateAttributes
from datadog_api_client.v2.model.metric_estimate_resource_type import MetricEstimateResourceType
from datadog_api_client.v2.model.metric_estimate_response import MetricEstimateResponse
from datadog_api_client.v2.model.metric_estimate_type import MetricEstimateType
from datadog_api_client.v2.model.metric_ingested_indexed_volume import MetricIngestedIndexedVolume
from datadog_api_client.v2.model.metric_ingested_indexed_volume_attributes import MetricIngestedIndexedVolumeAttributes
from datadog_api_client.v2.model.metric_ingested_indexed_volume_type import MetricIngestedIndexedVolumeType
from datadog_api_client.v2.model.metric_intake_type import MetricIntakeType
from datadog_api_client.v2.model.metric_metadata import MetricMetadata
from datadog_api_client.v2.model.metric_origin import MetricOrigin
from datadog_api_client.v2.model.metric_payload import MetricPayload
from datadog_api_client.v2.model.metric_point import MetricPoint
from datadog_api_client.v2.model.metric_resource import MetricResource
from datadog_api_client.v2.model.metric_series import MetricSeries
from datadog_api_client.v2.model.metric_suggested_aggregations import MetricSuggestedAggregations
from datadog_api_client.v2.model.metric_suggested_tags_and_aggregations import MetricSuggestedTagsAndAggregations
from datadog_api_client.v2.model.metric_suggested_tags_and_aggregations_response import (
    MetricSuggestedTagsAndAggregationsResponse,
)
from datadog_api_client.v2.model.metric_suggested_tags_attributes import MetricSuggestedTagsAttributes
from datadog_api_client.v2.model.metric_tag_configuration import MetricTagConfiguration
from datadog_api_client.v2.model.metric_tag_configuration_attributes import MetricTagConfigurationAttributes
from datadog_api_client.v2.model.metric_tag_configuration_create_attributes import (
    MetricTagConfigurationCreateAttributes,
)
from datadog_api_client.v2.model.metric_tag_configuration_create_data import MetricTagConfigurationCreateData
from datadog_api_client.v2.model.metric_tag_configuration_create_request import MetricTagConfigurationCreateRequest
from datadog_api_client.v2.model.metric_tag_configuration_metric_types import MetricTagConfigurationMetricTypes
from datadog_api_client.v2.model.metric_tag_configuration_response import MetricTagConfigurationResponse
from datadog_api_client.v2.model.metric_tag_configuration_type import MetricTagConfigurationType
from datadog_api_client.v2.model.metric_tag_configuration_update_attributes import (
    MetricTagConfigurationUpdateAttributes,
)
from datadog_api_client.v2.model.metric_tag_configuration_update_data import MetricTagConfigurationUpdateData
from datadog_api_client.v2.model.metric_tag_configuration_update_request import MetricTagConfigurationUpdateRequest
from datadog_api_client.v2.model.metric_type import MetricType
from datadog_api_client.v2.model.metric_volumes import MetricVolumes
from datadog_api_client.v2.model.metric_volumes_response import MetricVolumesResponse
from datadog_api_client.v2.model.metrics_aggregator import MetricsAggregator
from datadog_api_client.v2.model.metrics_and_metric_tag_configurations import MetricsAndMetricTagConfigurations
from datadog_api_client.v2.model.metrics_and_metric_tag_configurations_response import (
    MetricsAndMetricTagConfigurationsResponse,
)
from datadog_api_client.v2.model.metrics_data_source import MetricsDataSource
from datadog_api_client.v2.model.metrics_scalar_query import MetricsScalarQuery
from datadog_api_client.v2.model.metrics_timeseries_query import MetricsTimeseriesQuery
from datadog_api_client.v2.model.monitor_type import MonitorType
from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser
from datadog_api_client.v2.model.nullable_relationship_to_user_data import NullableRelationshipToUserData
from datadog_api_client.v2.model.opsgenie_service_create_attributes import OpsgenieServiceCreateAttributes
from datadog_api_client.v2.model.opsgenie_service_create_data import OpsgenieServiceCreateData
from datadog_api_client.v2.model.opsgenie_service_create_request import OpsgenieServiceCreateRequest
from datadog_api_client.v2.model.opsgenie_service_region_type import OpsgenieServiceRegionType
from datadog_api_client.v2.model.opsgenie_service_response import OpsgenieServiceResponse
from datadog_api_client.v2.model.opsgenie_service_response_attributes import OpsgenieServiceResponseAttributes
from datadog_api_client.v2.model.opsgenie_service_response_data import OpsgenieServiceResponseData
from datadog_api_client.v2.model.opsgenie_service_type import OpsgenieServiceType
from datadog_api_client.v2.model.opsgenie_service_update_attributes import OpsgenieServiceUpdateAttributes
from datadog_api_client.v2.model.opsgenie_service_update_data import OpsgenieServiceUpdateData
from datadog_api_client.v2.model.opsgenie_service_update_request import OpsgenieServiceUpdateRequest
from datadog_api_client.v2.model.opsgenie_services_response import OpsgenieServicesResponse
from datadog_api_client.v2.model.organization import Organization
from datadog_api_client.v2.model.organization_attributes import OrganizationAttributes
from datadog_api_client.v2.model.organizations_type import OrganizationsType
from datadog_api_client.v2.model.pagination import Pagination
from datadog_api_client.v2.model.partial_api_key import PartialAPIKey
from datadog_api_client.v2.model.partial_api_key_attributes import PartialAPIKeyAttributes
from datadog_api_client.v2.model.partial_application_key import PartialApplicationKey
from datadog_api_client.v2.model.partial_application_key_attributes import PartialApplicationKeyAttributes
from datadog_api_client.v2.model.partial_application_key_response import PartialApplicationKeyResponse
from datadog_api_client.v2.model.permission import Permission
from datadog_api_client.v2.model.permission_attributes import PermissionAttributes
from datadog_api_client.v2.model.permissions_response import PermissionsResponse
from datadog_api_client.v2.model.permissions_type import PermissionsType
from datadog_api_client.v2.model.process_summaries_meta import ProcessSummariesMeta
from datadog_api_client.v2.model.process_summaries_meta_page import ProcessSummariesMetaPage
from datadog_api_client.v2.model.process_summaries_response import ProcessSummariesResponse
from datadog_api_client.v2.model.process_summary import ProcessSummary
from datadog_api_client.v2.model.process_summary_attributes import ProcessSummaryAttributes
from datadog_api_client.v2.model.process_summary_type import ProcessSummaryType
from datadog_api_client.v2.model.query_formula import QueryFormula
from datadog_api_client.v2.model.query_sort_order import QuerySortOrder
from datadog_api_client.v2.model.rum_aggregate_bucket_value import RUMAggregateBucketValue
from datadog_api_client.v2.model.rum_aggregate_bucket_value_timeseries import RUMAggregateBucketValueTimeseries
from datadog_api_client.v2.model.rum_aggregate_bucket_value_timeseries_point import (
    RUMAggregateBucketValueTimeseriesPoint,
)
from datadog_api_client.v2.model.rum_aggregate_request import RUMAggregateRequest
from datadog_api_client.v2.model.rum_aggregate_sort import RUMAggregateSort
from datadog_api_client.v2.model.rum_aggregate_sort_type import RUMAggregateSortType
from datadog_api_client.v2.model.rum_aggregation_buckets_response import RUMAggregationBucketsResponse
from datadog_api_client.v2.model.rum_aggregation_function import RUMAggregationFunction
from datadog_api_client.v2.model.rum_analytics_aggregate_response import RUMAnalyticsAggregateResponse
from datadog_api_client.v2.model.rum_application import RUMApplication
from datadog_api_client.v2.model.rum_application_attributes import RUMApplicationAttributes
from datadog_api_client.v2.model.rum_application_create import RUMApplicationCreate
from datadog_api_client.v2.model.rum_application_create_attributes import RUMApplicationCreateAttributes
from datadog_api_client.v2.model.rum_application_create_request import RUMApplicationCreateRequest
from datadog_api_client.v2.model.rum_application_create_type import RUMApplicationCreateType
from datadog_api_client.v2.model.rum_application_list import RUMApplicationList
from datadog_api_client.v2.model.rum_application_list_attributes import RUMApplicationListAttributes
from datadog_api_client.v2.model.rum_application_list_type import RUMApplicationListType
from datadog_api_client.v2.model.rum_application_response import RUMApplicationResponse
from datadog_api_client.v2.model.rum_application_type import RUMApplicationType
from datadog_api_client.v2.model.rum_application_update import RUMApplicationUpdate
from datadog_api_client.v2.model.rum_application_update_attributes import RUMApplicationUpdateAttributes
from datadog_api_client.v2.model.rum_application_update_request import RUMApplicationUpdateRequest
from datadog_api_client.v2.model.rum_application_update_type import RUMApplicationUpdateType
from datadog_api_client.v2.model.rum_applications_response import RUMApplicationsResponse
from datadog_api_client.v2.model.rum_bucket_response import RUMBucketResponse
from datadog_api_client.v2.model.rum_compute import RUMCompute
from datadog_api_client.v2.model.rum_compute_type import RUMComputeType
from datadog_api_client.v2.model.rum_event import RUMEvent
from datadog_api_client.v2.model.rum_event_attributes import RUMEventAttributes
from datadog_api_client.v2.model.rum_event_type import RUMEventType
from datadog_api_client.v2.model.rum_events_response import RUMEventsResponse
from datadog_api_client.v2.model.rum_group_by import RUMGroupBy
from datadog_api_client.v2.model.rum_group_by_histogram import RUMGroupByHistogram
from datadog_api_client.v2.model.rum_group_by_missing import RUMGroupByMissing
from datadog_api_client.v2.model.rum_group_by_total import RUMGroupByTotal
from datadog_api_client.v2.model.rum_query_filter import RUMQueryFilter
from datadog_api_client.v2.model.rum_query_options import RUMQueryOptions
from datadog_api_client.v2.model.rum_query_page_options import RUMQueryPageOptions
from datadog_api_client.v2.model.rum_response_links import RUMResponseLinks
from datadog_api_client.v2.model.rum_response_metadata import RUMResponseMetadata
from datadog_api_client.v2.model.rum_response_page import RUMResponsePage
from datadog_api_client.v2.model.rum_response_status import RUMResponseStatus
from datadog_api_client.v2.model.rum_search_events_request import RUMSearchEventsRequest
from datadog_api_client.v2.model.rum_sort import RUMSort
from datadog_api_client.v2.model.rum_sort_order import RUMSortOrder
from datadog_api_client.v2.model.rum_warning import RUMWarning
from datadog_api_client.v2.model.relationship_to_incident_attachment import RelationshipToIncidentAttachment
from datadog_api_client.v2.model.relationship_to_incident_attachment_data import RelationshipToIncidentAttachmentData
from datadog_api_client.v2.model.relationship_to_incident_integration_metadata_data import (
    RelationshipToIncidentIntegrationMetadataData,
)
from datadog_api_client.v2.model.relationship_to_incident_integration_metadatas import (
    RelationshipToIncidentIntegrationMetadatas,
)
from datadog_api_client.v2.model.relationship_to_incident_postmortem import RelationshipToIncidentPostmortem
from datadog_api_client.v2.model.relationship_to_incident_postmortem_data import RelationshipToIncidentPostmortemData
from datadog_api_client.v2.model.relationship_to_organization import RelationshipToOrganization
from datadog_api_client.v2.model.relationship_to_organization_data import RelationshipToOrganizationData
from datadog_api_client.v2.model.relationship_to_organizations import RelationshipToOrganizations
from datadog_api_client.v2.model.relationship_to_permission import RelationshipToPermission
from datadog_api_client.v2.model.relationship_to_permission_data import RelationshipToPermissionData
from datadog_api_client.v2.model.relationship_to_permissions import RelationshipToPermissions
from datadog_api_client.v2.model.relationship_to_role import RelationshipToRole
from datadog_api_client.v2.model.relationship_to_role_data import RelationshipToRoleData
from datadog_api_client.v2.model.relationship_to_roles import RelationshipToRoles
from datadog_api_client.v2.model.relationship_to_saml_assertion_attribute import RelationshipToSAMLAssertionAttribute
from datadog_api_client.v2.model.relationship_to_saml_assertion_attribute_data import (
    RelationshipToSAMLAssertionAttributeData,
)
from datadog_api_client.v2.model.relationship_to_user import RelationshipToUser
from datadog_api_client.v2.model.relationship_to_user_data import RelationshipToUserData
from datadog_api_client.v2.model.relationship_to_users import RelationshipToUsers
from datadog_api_client.v2.model.response_meta_attributes import ResponseMetaAttributes
from datadog_api_client.v2.model.role import Role
from datadog_api_client.v2.model.role_attributes import RoleAttributes
from datadog_api_client.v2.model.role_clone import RoleClone
from datadog_api_client.v2.model.role_clone_attributes import RoleCloneAttributes
from datadog_api_client.v2.model.role_clone_request import RoleCloneRequest
from datadog_api_client.v2.model.role_create_attributes import RoleCreateAttributes
from datadog_api_client.v2.model.role_create_data import RoleCreateData
from datadog_api_client.v2.model.role_create_request import RoleCreateRequest
from datadog_api_client.v2.model.role_create_response import RoleCreateResponse
from datadog_api_client.v2.model.role_create_response_data import RoleCreateResponseData
from datadog_api_client.v2.model.role_relationships import RoleRelationships
from datadog_api_client.v2.model.role_response import RoleResponse
from datadog_api_client.v2.model.role_response_relationships import RoleResponseRelationships
from datadog_api_client.v2.model.role_update_attributes import RoleUpdateAttributes
from datadog_api_client.v2.model.role_update_data import RoleUpdateData
from datadog_api_client.v2.model.role_update_request import RoleUpdateRequest
from datadog_api_client.v2.model.role_update_response import RoleUpdateResponse
from datadog_api_client.v2.model.role_update_response_data import RoleUpdateResponseData
from datadog_api_client.v2.model.roles_response import RolesResponse
from datadog_api_client.v2.model.roles_sort import RolesSort
from datadog_api_client.v2.model.roles_type import RolesType
from datadog_api_client.v2.model.saml_assertion_attribute import SAMLAssertionAttribute
from datadog_api_client.v2.model.saml_assertion_attribute_attributes import SAMLAssertionAttributeAttributes
from datadog_api_client.v2.model.saml_assertion_attributes_type import SAMLAssertionAttributesType
from datadog_api_client.v2.model.scalar_column import ScalarColumn
from datadog_api_client.v2.model.scalar_formula_query_request import ScalarFormulaQueryRequest
from datadog_api_client.v2.model.scalar_formula_query_response import ScalarFormulaQueryResponse
from datadog_api_client.v2.model.scalar_formula_request import ScalarFormulaRequest
from datadog_api_client.v2.model.scalar_formula_request_attributes import ScalarFormulaRequestAttributes
from datadog_api_client.v2.model.scalar_formula_request_queries import ScalarFormulaRequestQueries
from datadog_api_client.v2.model.scalar_formula_request_type import ScalarFormulaRequestType
from datadog_api_client.v2.model.scalar_formula_response_atrributes import ScalarFormulaResponseAtrributes
from datadog_api_client.v2.model.scalar_formula_response_type import ScalarFormulaResponseType
from datadog_api_client.v2.model.scalar_query import ScalarQuery
from datadog_api_client.v2.model.scalar_response import ScalarResponse
from datadog_api_client.v2.model.scalar_response_series_list import ScalarResponseSeriesList
from datadog_api_client.v2.model.security_filter import SecurityFilter
from datadog_api_client.v2.model.security_filter_attributes import SecurityFilterAttributes
from datadog_api_client.v2.model.security_filter_create_attributes import SecurityFilterCreateAttributes
from datadog_api_client.v2.model.security_filter_create_data import SecurityFilterCreateData
from datadog_api_client.v2.model.security_filter_create_request import SecurityFilterCreateRequest
from datadog_api_client.v2.model.security_filter_exclusion_filter import SecurityFilterExclusionFilter
from datadog_api_client.v2.model.security_filter_exclusion_filter_response import SecurityFilterExclusionFilterResponse
from datadog_api_client.v2.model.security_filter_filtered_data_type import SecurityFilterFilteredDataType
from datadog_api_client.v2.model.security_filter_meta import SecurityFilterMeta
from datadog_api_client.v2.model.security_filter_response import SecurityFilterResponse
from datadog_api_client.v2.model.security_filter_type import SecurityFilterType
from datadog_api_client.v2.model.security_filter_update_attributes import SecurityFilterUpdateAttributes
from datadog_api_client.v2.model.security_filter_update_data import SecurityFilterUpdateData
from datadog_api_client.v2.model.security_filter_update_request import SecurityFilterUpdateRequest
from datadog_api_client.v2.model.security_filters_response import SecurityFiltersResponse
from datadog_api_client.v2.model.security_monitoring_filter import SecurityMonitoringFilter
from datadog_api_client.v2.model.security_monitoring_filter_action import SecurityMonitoringFilterAction
from datadog_api_client.v2.model.security_monitoring_list_rules_response import SecurityMonitoringListRulesResponse
from datadog_api_client.v2.model.security_monitoring_rule_case import SecurityMonitoringRuleCase
from datadog_api_client.v2.model.security_monitoring_rule_case_create import SecurityMonitoringRuleCaseCreate
from datadog_api_client.v2.model.security_monitoring_rule_create_payload import SecurityMonitoringRuleCreatePayload
from datadog_api_client.v2.model.security_monitoring_rule_detection_method import SecurityMonitoringRuleDetectionMethod
from datadog_api_client.v2.model.security_monitoring_rule_evaluation_window import (
    SecurityMonitoringRuleEvaluationWindow,
)
from datadog_api_client.v2.model.security_monitoring_rule_hardcoded_evaluator_type import (
    SecurityMonitoringRuleHardcodedEvaluatorType,
)
from datadog_api_client.v2.model.security_monitoring_rule_impossible_travel_options import (
    SecurityMonitoringRuleImpossibleTravelOptions,
)
from datadog_api_client.v2.model.security_monitoring_rule_keep_alive import SecurityMonitoringRuleKeepAlive
from datadog_api_client.v2.model.security_monitoring_rule_max_signal_duration import (
    SecurityMonitoringRuleMaxSignalDuration,
)
from datadog_api_client.v2.model.security_monitoring_rule_new_value_options import SecurityMonitoringRuleNewValueOptions
from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_forget_after import (
    SecurityMonitoringRuleNewValueOptionsForgetAfter,
)
from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_duration import (
    SecurityMonitoringRuleNewValueOptionsLearningDuration,
)
from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_method import (
    SecurityMonitoringRuleNewValueOptionsLearningMethod,
)
from datadog_api_client.v2.model.security_monitoring_rule_new_value_options_learning_threshold import (
    SecurityMonitoringRuleNewValueOptionsLearningThreshold,
)
from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
from datadog_api_client.v2.model.security_monitoring_rule_query import SecurityMonitoringRuleQuery
from datadog_api_client.v2.model.security_monitoring_rule_query_aggregation import (
    SecurityMonitoringRuleQueryAggregation,
)
from datadog_api_client.v2.model.security_monitoring_rule_response import SecurityMonitoringRuleResponse
from datadog_api_client.v2.model.security_monitoring_rule_severity import SecurityMonitoringRuleSeverity
from datadog_api_client.v2.model.security_monitoring_rule_type_create import SecurityMonitoringRuleTypeCreate
from datadog_api_client.v2.model.security_monitoring_rule_type_read import SecurityMonitoringRuleTypeRead
from datadog_api_client.v2.model.security_monitoring_rule_update_payload import SecurityMonitoringRuleUpdatePayload
from datadog_api_client.v2.model.security_monitoring_signal import SecurityMonitoringSignal
from datadog_api_client.v2.model.security_monitoring_signal_archive_reason import SecurityMonitoringSignalArchiveReason
from datadog_api_client.v2.model.security_monitoring_signal_assignee_update_attributes import (
    SecurityMonitoringSignalAssigneeUpdateAttributes,
)
from datadog_api_client.v2.model.security_monitoring_signal_assignee_update_data import (
    SecurityMonitoringSignalAssigneeUpdateData,
)
from datadog_api_client.v2.model.security_monitoring_signal_assignee_update_request import (
    SecurityMonitoringSignalAssigneeUpdateRequest,
)
from datadog_api_client.v2.model.security_monitoring_signal_attributes import SecurityMonitoringSignalAttributes
from datadog_api_client.v2.model.security_monitoring_signal_incident_ids import SecurityMonitoringSignalIncidentIds
from datadog_api_client.v2.model.security_monitoring_signal_incidents_update_attributes import (
    SecurityMonitoringSignalIncidentsUpdateAttributes,
)
from datadog_api_client.v2.model.security_monitoring_signal_incidents_update_data import (
    SecurityMonitoringSignalIncidentsUpdateData,
)
from datadog_api_client.v2.model.security_monitoring_signal_incidents_update_request import (
    SecurityMonitoringSignalIncidentsUpdateRequest,
)
from datadog_api_client.v2.model.security_monitoring_signal_list_request import SecurityMonitoringSignalListRequest
from datadog_api_client.v2.model.security_monitoring_signal_list_request_filter import (
    SecurityMonitoringSignalListRequestFilter,
)
from datadog_api_client.v2.model.security_monitoring_signal_list_request_page import (
    SecurityMonitoringSignalListRequestPage,
)
from datadog_api_client.v2.model.security_monitoring_signal_rule_create_payload import (
    SecurityMonitoringSignalRuleCreatePayload,
)
from datadog_api_client.v2.model.security_monitoring_signal_rule_query import SecurityMonitoringSignalRuleQuery
from datadog_api_client.v2.model.security_monitoring_signal_rule_response import SecurityMonitoringSignalRuleResponse
from datadog_api_client.v2.model.security_monitoring_signal_rule_response_query import (
    SecurityMonitoringSignalRuleResponseQuery,
)
from datadog_api_client.v2.model.security_monitoring_signal_rule_type import SecurityMonitoringSignalRuleType
from datadog_api_client.v2.model.security_monitoring_signal_state import SecurityMonitoringSignalState
from datadog_api_client.v2.model.security_monitoring_signal_state_update_attributes import (
    SecurityMonitoringSignalStateUpdateAttributes,
)
from datadog_api_client.v2.model.security_monitoring_signal_state_update_data import (
    SecurityMonitoringSignalStateUpdateData,
)
from datadog_api_client.v2.model.security_monitoring_signal_state_update_request import (
    SecurityMonitoringSignalStateUpdateRequest,
)
from datadog_api_client.v2.model.security_monitoring_signal_triage_attributes import (
    SecurityMonitoringSignalTriageAttributes,
)
from datadog_api_client.v2.model.security_monitoring_signal_triage_update_data import (
    SecurityMonitoringSignalTriageUpdateData,
)
from datadog_api_client.v2.model.security_monitoring_signal_triage_update_response import (
    SecurityMonitoringSignalTriageUpdateResponse,
)
from datadog_api_client.v2.model.security_monitoring_signal_type import SecurityMonitoringSignalType
from datadog_api_client.v2.model.security_monitoring_signals_list_response import SecurityMonitoringSignalsListResponse
from datadog_api_client.v2.model.security_monitoring_signals_list_response_links import (
    SecurityMonitoringSignalsListResponseLinks,
)
from datadog_api_client.v2.model.security_monitoring_signals_list_response_meta import (
    SecurityMonitoringSignalsListResponseMeta,
)
from datadog_api_client.v2.model.security_monitoring_signals_list_response_meta_page import (
    SecurityMonitoringSignalsListResponseMetaPage,
)
from datadog_api_client.v2.model.security_monitoring_signals_sort import SecurityMonitoringSignalsSort
from datadog_api_client.v2.model.security_monitoring_standard_rule_create_payload import (
    SecurityMonitoringStandardRuleCreatePayload,
)
from datadog_api_client.v2.model.security_monitoring_standard_rule_query import SecurityMonitoringStandardRuleQuery
from datadog_api_client.v2.model.security_monitoring_standard_rule_response import (
    SecurityMonitoringStandardRuleResponse,
)
from datadog_api_client.v2.model.security_monitoring_triage_user import SecurityMonitoringTriageUser
from datadog_api_client.v2.model.sensitive_data_scanner_config_request import SensitiveDataScannerConfigRequest
from datadog_api_client.v2.model.sensitive_data_scanner_configuration import SensitiveDataScannerConfiguration
from datadog_api_client.v2.model.sensitive_data_scanner_configuration_data import SensitiveDataScannerConfigurationData
from datadog_api_client.v2.model.sensitive_data_scanner_configuration_relationships import (
    SensitiveDataScannerConfigurationRelationships,
)
from datadog_api_client.v2.model.sensitive_data_scanner_configuration_type import SensitiveDataScannerConfigurationType
from datadog_api_client.v2.model.sensitive_data_scanner_create_group_response import (
    SensitiveDataScannerCreateGroupResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_create_rule_response import (
    SensitiveDataScannerCreateRuleResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_filter import SensitiveDataScannerFilter
from datadog_api_client.v2.model.sensitive_data_scanner_get_config_included_array import (
    SensitiveDataScannerGetConfigIncludedArray,
)
from datadog_api_client.v2.model.sensitive_data_scanner_get_config_included_item import (
    SensitiveDataScannerGetConfigIncludedItem,
)
from datadog_api_client.v2.model.sensitive_data_scanner_get_config_response import SensitiveDataScannerGetConfigResponse
from datadog_api_client.v2.model.sensitive_data_scanner_get_config_response_data import (
    SensitiveDataScannerGetConfigResponseData,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group import SensitiveDataScannerGroup
from datadog_api_client.v2.model.sensitive_data_scanner_group_attributes import SensitiveDataScannerGroupAttributes
from datadog_api_client.v2.model.sensitive_data_scanner_group_create import SensitiveDataScannerGroupCreate
from datadog_api_client.v2.model.sensitive_data_scanner_group_create_request import (
    SensitiveDataScannerGroupCreateRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_data import SensitiveDataScannerGroupData
from datadog_api_client.v2.model.sensitive_data_scanner_group_delete_request import (
    SensitiveDataScannerGroupDeleteRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_delete_response import (
    SensitiveDataScannerGroupDeleteResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_included_item import SensitiveDataScannerGroupIncludedItem
from datadog_api_client.v2.model.sensitive_data_scanner_group_item import SensitiveDataScannerGroupItem
from datadog_api_client.v2.model.sensitive_data_scanner_group_list import SensitiveDataScannerGroupList
from datadog_api_client.v2.model.sensitive_data_scanner_group_relationships import (
    SensitiveDataScannerGroupRelationships,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_response import SensitiveDataScannerGroupResponse
from datadog_api_client.v2.model.sensitive_data_scanner_group_type import SensitiveDataScannerGroupType
from datadog_api_client.v2.model.sensitive_data_scanner_group_update import SensitiveDataScannerGroupUpdate
from datadog_api_client.v2.model.sensitive_data_scanner_group_update_request import (
    SensitiveDataScannerGroupUpdateRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_update_response import (
    SensitiveDataScannerGroupUpdateResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_meta import SensitiveDataScannerMeta
from datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only import SensitiveDataScannerMetaVersionOnly
from datadog_api_client.v2.model.sensitive_data_scanner_product import SensitiveDataScannerProduct
from datadog_api_client.v2.model.sensitive_data_scanner_reorder_config import SensitiveDataScannerReorderConfig
from datadog_api_client.v2.model.sensitive_data_scanner_reorder_groups_response import (
    SensitiveDataScannerReorderGroupsResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_rule import SensitiveDataScannerRule
from datadog_api_client.v2.model.sensitive_data_scanner_rule_attributes import SensitiveDataScannerRuleAttributes
from datadog_api_client.v2.model.sensitive_data_scanner_rule_create import SensitiveDataScannerRuleCreate
from datadog_api_client.v2.model.sensitive_data_scanner_rule_create_request import SensitiveDataScannerRuleCreateRequest
from datadog_api_client.v2.model.sensitive_data_scanner_rule_data import SensitiveDataScannerRuleData
from datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_request import SensitiveDataScannerRuleDeleteRequest
from datadog_api_client.v2.model.sensitive_data_scanner_rule_delete_response import (
    SensitiveDataScannerRuleDeleteResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_rule_included_item import SensitiveDataScannerRuleIncludedItem
from datadog_api_client.v2.model.sensitive_data_scanner_rule_relationships import SensitiveDataScannerRuleRelationships
from datadog_api_client.v2.model.sensitive_data_scanner_rule_response import SensitiveDataScannerRuleResponse
from datadog_api_client.v2.model.sensitive_data_scanner_rule_type import SensitiveDataScannerRuleType
from datadog_api_client.v2.model.sensitive_data_scanner_rule_update import SensitiveDataScannerRuleUpdate
from datadog_api_client.v2.model.sensitive_data_scanner_rule_update_request import SensitiveDataScannerRuleUpdateRequest
from datadog_api_client.v2.model.sensitive_data_scanner_rule_update_response import (
    SensitiveDataScannerRuleUpdateResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern import SensitiveDataScannerStandardPattern
from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_attributes import (
    SensitiveDataScannerStandardPatternAttributes,
)
from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_data import (
    SensitiveDataScannerStandardPatternData,
)
from datadog_api_client.v2.model.sensitive_data_scanner_standard_pattern_type import (
    SensitiveDataScannerStandardPatternType,
)
from datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response import (
    SensitiveDataScannerStandardPatternsResponse,
)
from datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response_data import (
    SensitiveDataScannerStandardPatternsResponseData,
)
from datadog_api_client.v2.model.sensitive_data_scanner_standard_patterns_response_item import (
    SensitiveDataScannerStandardPatternsResponseItem,
)
from datadog_api_client.v2.model.sensitive_data_scanner_text_replacement import SensitiveDataScannerTextReplacement
from datadog_api_client.v2.model.sensitive_data_scanner_text_replacement_type import (
    SensitiveDataScannerTextReplacementType,
)
from datadog_api_client.v2.model.service_account_create_attributes import ServiceAccountCreateAttributes
from datadog_api_client.v2.model.service_account_create_data import ServiceAccountCreateData
from datadog_api_client.v2.model.service_account_create_request import ServiceAccountCreateRequest
from datadog_api_client.v2.model.service_definition_create_response import ServiceDefinitionCreateResponse
from datadog_api_client.v2.model.service_definition_data import ServiceDefinitionData
from datadog_api_client.v2.model.service_definition_data_attributes import ServiceDefinitionDataAttributes
from datadog_api_client.v2.model.service_definition_get_response import ServiceDefinitionGetResponse
from datadog_api_client.v2.model.service_definition_meta import ServiceDefinitionMeta
from datadog_api_client.v2.model.service_definition_schema import ServiceDefinitionSchema
from datadog_api_client.v2.model.service_definition_v1 import ServiceDefinitionV1
from datadog_api_client.v2.model.service_definition_v1_contact import ServiceDefinitionV1Contact
from datadog_api_client.v2.model.service_definition_v1_info import ServiceDefinitionV1Info
from datadog_api_client.v2.model.service_definition_v1_integrations import ServiceDefinitionV1Integrations
from datadog_api_client.v2.model.service_definition_v1_org import ServiceDefinitionV1Org
from datadog_api_client.v2.model.service_definition_v1_resource import ServiceDefinitionV1Resource
from datadog_api_client.v2.model.service_definition_v1_resource_type import ServiceDefinitionV1ResourceType
from datadog_api_client.v2.model.service_definition_v1_version import ServiceDefinitionV1Version
from datadog_api_client.v2.model.service_definition_v2 import ServiceDefinitionV2
from datadog_api_client.v2.model.service_definition_v2_contact import ServiceDefinitionV2Contact
from datadog_api_client.v2.model.service_definition_v2_doc import ServiceDefinitionV2Doc
from datadog_api_client.v2.model.service_definition_v2_email import ServiceDefinitionV2Email
from datadog_api_client.v2.model.service_definition_v2_email_type import ServiceDefinitionV2EmailType
from datadog_api_client.v2.model.service_definition_v2_integrations import ServiceDefinitionV2Integrations
from datadog_api_client.v2.model.service_definition_v2_link import ServiceDefinitionV2Link
from datadog_api_client.v2.model.service_definition_v2_link_type import ServiceDefinitionV2LinkType
from datadog_api_client.v2.model.service_definition_v2_opsgenie import ServiceDefinitionV2Opsgenie
from datadog_api_client.v2.model.service_definition_v2_opsgenie_region import ServiceDefinitionV2OpsgenieRegion
from datadog_api_client.v2.model.service_definition_v2_repo import ServiceDefinitionV2Repo
from datadog_api_client.v2.model.service_definition_v2_slack import ServiceDefinitionV2Slack
from datadog_api_client.v2.model.service_definition_v2_slack_type import ServiceDefinitionV2SlackType
from datadog_api_client.v2.model.service_definition_v2_version import ServiceDefinitionV2Version
from datadog_api_client.v2.model.service_definitions_create_request import ServiceDefinitionsCreateRequest
from datadog_api_client.v2.model.service_definitions_list_response import ServiceDefinitionsListResponse
from datadog_api_client.v2.model.tags_event_attribute import TagsEventAttribute
from datadog_api_client.v2.model.timeseries_formula_query_request import TimeseriesFormulaQueryRequest
from datadog_api_client.v2.model.timeseries_formula_query_response import TimeseriesFormulaQueryResponse
from datadog_api_client.v2.model.timeseries_formula_request import TimeseriesFormulaRequest
from datadog_api_client.v2.model.timeseries_formula_request_attributes import TimeseriesFormulaRequestAttributes
from datadog_api_client.v2.model.timeseries_formula_request_queries import TimeseriesFormulaRequestQueries
from datadog_api_client.v2.model.timeseries_formula_request_type import TimeseriesFormulaRequestType
from datadog_api_client.v2.model.timeseries_formula_response_type import TimeseriesFormulaResponseType
from datadog_api_client.v2.model.timeseries_query import TimeseriesQuery
from datadog_api_client.v2.model.timeseries_response import TimeseriesResponse
from datadog_api_client.v2.model.timeseries_response_attributes import TimeseriesResponseAttributes
from datadog_api_client.v2.model.timeseries_response_series import TimeseriesResponseSeries
from datadog_api_client.v2.model.timeseries_response_series_list import TimeseriesResponseSeriesList
from datadog_api_client.v2.model.timeseries_response_times import TimeseriesResponseTimes
from datadog_api_client.v2.model.timeseries_response_values import TimeseriesResponseValues
from datadog_api_client.v2.model.timeseries_response_values_list import TimeseriesResponseValuesList
from datadog_api_client.v2.model.unit import Unit
from datadog_api_client.v2.model.usage_application_security_monitoring_response import (
    UsageApplicationSecurityMonitoringResponse,
)
from datadog_api_client.v2.model.usage_attributes_object import UsageAttributesObject
from datadog_api_client.v2.model.usage_data_object import UsageDataObject
from datadog_api_client.v2.model.usage_lambda_traced_invocations_response import UsageLambdaTracedInvocationsResponse
from datadog_api_client.v2.model.usage_observability_pipelines_response import UsageObservabilityPipelinesResponse
from datadog_api_client.v2.model.usage_time_series_object import UsageTimeSeriesObject
from datadog_api_client.v2.model.usage_time_series_type import UsageTimeSeriesType
from datadog_api_client.v2.model.user import User
from datadog_api_client.v2.model.user_attributes import UserAttributes
from datadog_api_client.v2.model.user_create_attributes import UserCreateAttributes
from datadog_api_client.v2.model.user_create_data import UserCreateData
from datadog_api_client.v2.model.user_create_request import UserCreateRequest
from datadog_api_client.v2.model.user_invitation_data import UserInvitationData
from datadog_api_client.v2.model.user_invitation_data_attributes import UserInvitationDataAttributes
from datadog_api_client.v2.model.user_invitation_relationships import UserInvitationRelationships
from datadog_api_client.v2.model.user_invitation_response import UserInvitationResponse
from datadog_api_client.v2.model.user_invitation_response_data import UserInvitationResponseData
from datadog_api_client.v2.model.user_invitations_request import UserInvitationsRequest
from datadog_api_client.v2.model.user_invitations_response import UserInvitationsResponse
from datadog_api_client.v2.model.user_invitations_type import UserInvitationsType
from datadog_api_client.v2.model.user_relationships import UserRelationships
from datadog_api_client.v2.model.user_response import UserResponse
from datadog_api_client.v2.model.user_response_included_item import UserResponseIncludedItem
from datadog_api_client.v2.model.user_response_relationships import UserResponseRelationships
from datadog_api_client.v2.model.user_update_attributes import UserUpdateAttributes
from datadog_api_client.v2.model.user_update_data import UserUpdateData
from datadog_api_client.v2.model.user_update_request import UserUpdateRequest
from datadog_api_client.v2.model.users_response import UsersResponse
from datadog_api_client.v2.model.users_type import UsersType



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slo_bulk_delete_response_data import SLOBulkDeleteResponseData
    from datadog_api_client.v1.model.slo_bulk_delete_error import SLOBulkDeleteError


class SLOBulkDeleteResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slo_bulk_delete_response_data import SLOBulkDeleteResponseData
        from datadog_api_client.v1.model.slo_bulk_delete_error import SLOBulkDeleteError

        return {
            "data": (SLOBulkDeleteResponseData,),
            "errors": ([SLOBulkDeleteError],),
        }

    attribute_map = {
        "data": "data",
        "errors": "errors",
    }

    def __init__(
        self_,
        data: Union[SLOBulkDeleteResponseData, UnsetType] = unset,
        errors: Union[List[SLOBulkDeleteError], UnsetType] = unset,
        **kwargs,
    ):
        """
        The bulk partial delete service level objective object endpoint
        response.

        This endpoint operates on multiple service level objective objects, so
        it may be partially successful. In such cases, the "data" and "error"
        fields in this response indicate which deletions succeeded and failed.

        :param data: An array of service level objective objects.
        :type data: SLOBulkDeleteResponseData, optional

        :param errors: Array of errors object returned.
        :type errors: [SLOBulkDeleteError], optional
        """
        if data is not unset:
            kwargs["data"] = data
        if errors is not unset:
            kwargs["errors"] = errors
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.widget_tick_edge import WidgetTickEdge
    from datadog_api_client.v1.model.note_widget_definition_type import NoteWidgetDefinitionType
    from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign


class NoteWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.widget_tick_edge import WidgetTickEdge
        from datadog_api_client.v1.model.note_widget_definition_type import NoteWidgetDefinitionType
        from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign

        return {
            "background_color": (str,),
            "content": (str,),
            "font_size": (str,),
            "has_padding": (bool,),
            "show_tick": (bool,),
            "text_align": (WidgetTextAlign,),
            "tick_edge": (WidgetTickEdge,),
            "tick_pos": (str,),
            "type": (NoteWidgetDefinitionType,),
            "vertical_align": (WidgetVerticalAlign,),
        }

    attribute_map = {
        "background_color": "background_color",
        "content": "content",
        "font_size": "font_size",
        "has_padding": "has_padding",
        "show_tick": "show_tick",
        "text_align": "text_align",
        "tick_edge": "tick_edge",
        "tick_pos": "tick_pos",
        "type": "type",
        "vertical_align": "vertical_align",
    }

    def __init__(
        self_,
        content: str,
        type: NoteWidgetDefinitionType,
        background_color: Union[str, UnsetType] = unset,
        font_size: Union[str, UnsetType] = unset,
        has_padding: Union[bool, UnsetType] = unset,
        show_tick: Union[bool, UnsetType] = unset,
        text_align: Union[WidgetTextAlign, UnsetType] = unset,
        tick_edge: Union[WidgetTickEdge, UnsetType] = unset,
        tick_pos: Union[str, UnsetType] = unset,
        vertical_align: Union[WidgetVerticalAlign, UnsetType] = unset,
        **kwargs,
    ):
        """
        The notes and links widget is similar to free text widget, but allows for more formatting options.

        :param background_color: Background color of the note.
        :type background_color: str, optional

        :param content: Content of the note.
        :type content: str

        :param font_size: Size of the text.
        :type font_size: str, optional

        :param has_padding: Whether to add padding or not.
        :type has_padding: bool, optional

        :param show_tick: Whether to show a tick or not.
        :type show_tick: bool, optional

        :param text_align: How to align the text on the widget.
        :type text_align: WidgetTextAlign, optional

        :param tick_edge: Define how you want to align the text on the widget.
        :type tick_edge: WidgetTickEdge, optional

        :param tick_pos: Where to position the tick on an edge.
        :type tick_pos: str, optional

        :param type: Type of the note widget.
        :type type: NoteWidgetDefinitionType

        :param vertical_align: Vertical alignment.
        :type vertical_align: WidgetVerticalAlign, optional
        """
        if background_color is not unset:
            kwargs["background_color"] = background_color
        if font_size is not unset:
            kwargs["font_size"] = font_size
        if has_padding is not unset:
            kwargs["has_padding"] = has_padding
        if show_tick is not unset:
            kwargs["show_tick"] = show_tick
        if text_align is not unset:
            kwargs["text_align"] = text_align
        if tick_edge is not unset:
            kwargs["tick_edge"] = tick_edge
        if tick_pos is not unset:
            kwargs["tick_pos"] = tick_pos
        if vertical_align is not unset:
            kwargs["vertical_align"] = vertical_align
        super().__init__(kwargs)

        self_.content = content
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MetricEstimateType(ModelSimple):
    """
    Estimate type based on the queried configuration. By default, `count_or_gauge` is returned. `distribution` is returned for distribution metrics without percentiles enabled. Lastly, `percentile` is returned if `filter[pct]=true` is queried with a distribution metric.

    :param value: If omitted defaults to "count_or_gauge". Must be one of ["count_or_gauge", "distribution", "percentile"].
    :type value: str
    """

    allowed_values = {
        "count_or_gauge",
        "distribution",
        "percentile",
    }
    COUNT_OR_GAUGE: ClassVar["MetricEstimateType"]
    DISTRIBUTION: ClassVar["MetricEstimateType"]
    PERCENTILE: ClassVar["MetricEstimateType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MetricEstimateType.COUNT_OR_GAUGE = MetricEstimateType("count_or_gauge")
MetricEstimateType.DISTRIBUTION = MetricEstimateType("distribution")
MetricEstimateType.PERCENTILE = MetricEstimateType("percentile")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_ssl_certificate import SyntheticsSSLCertificate
    from datadog_api_client.v1.model.synthetics_test_process_status import SyntheticsTestProcessStatus
    from datadog_api_client.v1.model.synthetics_api_test_result_failure import SyntheticsApiTestResultFailure
    from datadog_api_client.v1.model.synthetics_timing import SyntheticsTiming


class SyntheticsAPITestResultData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_ssl_certificate import SyntheticsSSLCertificate
        from datadog_api_client.v1.model.synthetics_test_process_status import SyntheticsTestProcessStatus
        from datadog_api_client.v1.model.synthetics_api_test_result_failure import SyntheticsApiTestResultFailure
        from datadog_api_client.v1.model.synthetics_timing import SyntheticsTiming

        return {
            "cert": (SyntheticsSSLCertificate,),
            "event_type": (SyntheticsTestProcessStatus,),
            "failure": (SyntheticsApiTestResultFailure,),
            "http_status_code": (int,),
            "request_headers": ({str: (dict,)},),
            "response_body": (str,),
            "response_headers": (
                {
                    str: (
                        bool,
                        date,
                        datetime,
                        dict,
                        float,
                        int,
                        list,
                        str,
                        none_type,
                    )
                },
            ),
            "response_size": (int,),
            "timings": (SyntheticsTiming,),
        }

    attribute_map = {
        "cert": "cert",
        "event_type": "eventType",
        "failure": "failure",
        "http_status_code": "httpStatusCode",
        "request_headers": "requestHeaders",
        "response_body": "responseBody",
        "response_headers": "responseHeaders",
        "response_size": "responseSize",
        "timings": "timings",
    }

    def __init__(
        self_,
        cert: Union[SyntheticsSSLCertificate, UnsetType] = unset,
        event_type: Union[SyntheticsTestProcessStatus, UnsetType] = unset,
        failure: Union[SyntheticsApiTestResultFailure, UnsetType] = unset,
        http_status_code: Union[int, UnsetType] = unset,
        request_headers: Union[Dict[str, dict], UnsetType] = unset,
        response_body: Union[str, UnsetType] = unset,
        response_headers: Union[Dict[str, Any], UnsetType] = unset,
        response_size: Union[int, UnsetType] = unset,
        timings: Union[SyntheticsTiming, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing results for your Synthetic API test.

        :param cert: Object describing the SSL certificate used for a Synthetic test.
        :type cert: SyntheticsSSLCertificate, optional

        :param event_type: Status of a Synthetic test.
        :type event_type: SyntheticsTestProcessStatus, optional

        :param failure: The API test failure details.
        :type failure: SyntheticsApiTestResultFailure, optional

        :param http_status_code: The API test HTTP status code.
        :type http_status_code: int, optional

        :param request_headers: Request header object used for the API test.
        :type request_headers: {str: (dict,)}, optional

        :param response_body: Response body returned for the API test.
        :type response_body: str, optional

        :param response_headers: Response headers returned for the API test.
        :type response_headers: {str: (bool, date, datetime, dict, float, int, list, str, none_type,)}, optional

        :param response_size: Global size in byte of the API test response.
        :type response_size: int, optional

        :param timings: Object containing all metrics and their values collected for a Synthetic API test.
            Learn more about those metrics in `Synthetics documentation <https://docs.datadoghq.com/synthetics/#metrics>`_.
        :type timings: SyntheticsTiming, optional
        """
        if cert is not unset:
            kwargs["cert"] = cert
        if event_type is not unset:
            kwargs["event_type"] = event_type
        if failure is not unset:
            kwargs["failure"] = failure
        if http_status_code is not unset:
            kwargs["http_status_code"] = http_status_code
        if request_headers is not unset:
            kwargs["request_headers"] = request_headers
        if response_body is not unset:
            kwargs["response_body"] = response_body
        if response_headers is not unset:
            kwargs["response_headers"] = response_headers
        if response_size is not unset:
            kwargs["response_size"] = response_size
        if timings is not unset:
            kwargs["timings"] = timings
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

import collections
from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    set_attribute_from_path,
    get_attribute_from_path,
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.events_list_response import EventsListResponse
from datadog_api_client.v2.model.events_sort import EventsSort
from datadog_api_client.v2.model.event_response import EventResponse
from datadog_api_client.v2.model.events_list_request import EventsListRequest


class EventsApi:
    """
    The events service allows you to programmatically post events to the event stream
    and fetch events from the event stream. Events are limited to 4000 characters.
    If an event is sent out with a message containing more than 4000 characters, only the
    first 4000 characters are displayed.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._list_events_endpoint = _Endpoint(
            settings={
                "response_type": (EventsListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/events",
                "operation_id": "list_events",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "filter_query": {
                    "openapi_types": (str,),
                    "attribute": "filter[query]",
                    "location": "query",
                },
                "filter_from": {
                    "openapi_types": (str,),
                    "attribute": "filter[from]",
                    "location": "query",
                },
                "filter_to": {
                    "openapi_types": (str,),
                    "attribute": "filter[to]",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (EventsSort,),
                    "attribute": "sort",
                    "location": "query",
                },
                "page_cursor": {
                    "openapi_types": (str,),
                    "attribute": "page[cursor]",
                    "location": "query",
                },
                "page_limit": {
                    "validation": {
                        "inclusive_maximum": 1000,
                    },
                    "openapi_types": (int,),
                    "attribute": "page[limit]",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._search_events_endpoint = _Endpoint(
            settings={
                "response_type": (EventsListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/events/search",
                "operation_id": "search_events",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "openapi_types": (EventsListRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def list_events(
        self,
        *,
        filter_query: Union[str, UnsetType] = unset,
        filter_from: Union[str, UnsetType] = unset,
        filter_to: Union[str, UnsetType] = unset,
        sort: Union[EventsSort, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
    ) -> EventsListResponse:
        """Get a list of events.

        List endpoint returns events that match an events search query.
        `Results are paginated similarly to logs <https://docs.datadoghq.com/logs/guide/collect-multiple-logs-with-pagination>`_.

        Use this endpoint to see your latest events.

        :param filter_query: Search query following events syntax.
        :type filter_query: str, optional
        :param filter_from: Minimum timestamp for requested events.
        :type filter_from: str, optional
        :param filter_to: Maximum timestamp for requested events.
        :type filter_to: str, optional
        :param sort: Order of events in results.
        :type sort: EventsSort, optional
        :param page_cursor: List following results with a cursor provided in the previous query.
        :type page_cursor: str, optional
        :param page_limit: Maximum number of events in the response.
        :type page_limit: int, optional
        :rtype: EventsListResponse
        """
        kwargs: Dict[str, Any] = {}
        if filter_query is not unset:
            kwargs["filter_query"] = filter_query

        if filter_from is not unset:
            kwargs["filter_from"] = filter_from

        if filter_to is not unset:
            kwargs["filter_to"] = filter_to

        if sort is not unset:
            kwargs["sort"] = sort

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        return self._list_events_endpoint.call_with_http_info(**kwargs)

    def list_events_with_pagination(
        self,
        *,
        filter_query: Union[str, UnsetType] = unset,
        filter_from: Union[str, UnsetType] = unset,
        filter_to: Union[str, UnsetType] = unset,
        sort: Union[EventsSort, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
    ) -> collections.abc.Iterable[EventResponse]:
        """Get a list of events.

        Provide a paginated version of :meth:`list_events`, returning all items.

        :param filter_query: Search query following events syntax.
        :type filter_query: str, optional
        :param filter_from: Minimum timestamp for requested events.
        :type filter_from: str, optional
        :param filter_to: Maximum timestamp for requested events.
        :type filter_to: str, optional
        :param sort: Order of events in results.
        :type sort: EventsSort, optional
        :param page_cursor: List following results with a cursor provided in the previous query.
        :type page_cursor: str, optional
        :param page_limit: Maximum number of events in the response.
        :type page_limit: int, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[EventResponse]
        """
        kwargs: Dict[str, Any] = {}
        if filter_query is not unset:
            kwargs["filter_query"] = filter_query

        if filter_from is not unset:
            kwargs["filter_from"] = filter_from

        if filter_to is not unset:
            kwargs["filter_to"] = filter_to

        if sort is not unset:
            kwargs["sort"] = sort

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        local_page_size = get_attribute_from_path(kwargs, "page_limit", 10)
        endpoint = self._list_events_endpoint
        set_attribute_from_path(kwargs, "page_limit", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs, "page_cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
            )

    def search_events(
        self,
        *,
        body: Union[EventsListRequest, UnsetType] = unset,
    ) -> EventsListResponse:
        """Search events.

        List endpoint returns events that match an events search query.
        `Results are paginated similarly to logs <https://docs.datadoghq.com/logs/guide/collect-multiple-logs-with-pagination>`_.

        Use this endpoint to build complex events filtering and search.

        :type body: EventsListRequest, optional
        :rtype: EventsListResponse
        """
        kwargs: Dict[str, Any] = {}
        if body is not unset:
            kwargs["body"] = body

        return self._search_events_endpoint.call_with_http_info(**kwargs)

    def search_events_with_pagination(
        self,
        *,
        body: Union[EventsListRequest, UnsetType] = unset,
    ) -> collections.abc.Iterable[EventResponse]:
        """Search events.

        Provide a paginated version of :meth:`search_events`, returning all items.

        :type body: EventsListRequest, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[EventResponse]
        """
        kwargs: Dict[str, Any] = {}
        if body is not unset:
            kwargs["body"] = body

        local_page_size = get_attribute_from_path(kwargs, "body.page.limit", 10)
        endpoint = self._search_events_endpoint
        set_attribute_from_path(kwargs, "body.page.limit", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs, "body.page.cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
            )



"""
Update an index returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.logs_indexes_api import LogsIndexesApi
from datadog_api_client.v1.model.logs_exclusion import LogsExclusion
from datadog_api_client.v1.model.logs_exclusion_filter import LogsExclusionFilter
from datadog_api_client.v1.model.logs_filter import LogsFilter
from datadog_api_client.v1.model.logs_index_update_request import LogsIndexUpdateRequest

body = LogsIndexUpdateRequest(
    daily_limit=300000000,
    disable_daily_limit=False,
    exclusion_filters=[
        LogsExclusion(
            filter=LogsExclusionFilter(
                query="*",
                sample_rate=1.0,
            ),
            name="payment",
        ),
    ],
    filter=LogsFilter(
        query="source:python",
    ),
    num_retention_days=15,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsIndexesApi(api_client)
    response = api_instance.update_logs_index(name="name", body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.usage_billable_summary_keys import UsageBillableSummaryKeys


class UsageBillableSummaryHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.usage_billable_summary_keys import UsageBillableSummaryKeys

        return {
            "billing_plan": (str,),
            "end_date": (datetime,),
            "num_orgs": (int,),
            "org_name": (str,),
            "public_id": (str,),
            "ratio_in_month": (float,),
            "region": (str,),
            "start_date": (datetime,),
            "usage": (UsageBillableSummaryKeys,),
        }

    attribute_map = {
        "billing_plan": "billing_plan",
        "end_date": "end_date",
        "num_orgs": "num_orgs",
        "org_name": "org_name",
        "public_id": "public_id",
        "ratio_in_month": "ratio_in_month",
        "region": "region",
        "start_date": "start_date",
        "usage": "usage",
    }

    def __init__(
        self_,
        billing_plan: Union[str, UnsetType] = unset,
        end_date: Union[datetime, UnsetType] = unset,
        num_orgs: Union[int, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        ratio_in_month: Union[float, UnsetType] = unset,
        region: Union[str, UnsetType] = unset,
        start_date: Union[datetime, UnsetType] = unset,
        usage: Union[UsageBillableSummaryKeys, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response with monthly summary of data billed by Datadog.

        :param billing_plan: The billing plan.
        :type billing_plan: str, optional

        :param end_date: Shows the last date of usage.
        :type end_date: datetime, optional

        :param num_orgs: The number of organizations.
        :type num_orgs: int, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param ratio_in_month: Shows usage aggregation for a billing period.
        :type ratio_in_month: float, optional

        :param region: The region of the organization.
        :type region: str, optional

        :param start_date: Shows the first date of usage.
        :type start_date: datetime, optional

        :param usage: Response with aggregated usage types.
        :type usage: UsageBillableSummaryKeys, optional
        """
        if billing_plan is not unset:
            kwargs["billing_plan"] = billing_plan
        if end_date is not unset:
            kwargs["end_date"] = end_date
        if num_orgs is not unset:
            kwargs["num_orgs"] = num_orgs
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if ratio_in_month is not unset:
            kwargs["ratio_in_month"] = ratio_in_month
        if region is not unset:
            kwargs["region"] = region
        if start_date is not unset:
            kwargs["start_date"] = start_date
        if usage is not unset:
            kwargs["usage"] = usage
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.organization_billing import OrganizationBilling
    from datadog_api_client.v1.model.organization_settings import OrganizationSettings
    from datadog_api_client.v1.model.organization_subscription import OrganizationSubscription


class Organization(ModelNormal):
    validations = {
        "name": {
            "max_length": 32,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.organization_billing import OrganizationBilling
        from datadog_api_client.v1.model.organization_settings import OrganizationSettings
        from datadog_api_client.v1.model.organization_subscription import OrganizationSubscription

        return {
            "billing": (OrganizationBilling,),
            "created": (str,),
            "description": (str,),
            "name": (str,),
            "public_id": (str,),
            "settings": (OrganizationSettings,),
            "subscription": (OrganizationSubscription,),
            "trial": (bool,),
        }

    attribute_map = {
        "billing": "billing",
        "created": "created",
        "description": "description",
        "name": "name",
        "public_id": "public_id",
        "settings": "settings",
        "subscription": "subscription",
        "trial": "trial",
    }
    read_only_vars = {
        "created",
    }

    def __init__(
        self_,
        billing: Union[OrganizationBilling, UnsetType] = unset,
        created: Union[str, UnsetType] = unset,
        description: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        settings: Union[OrganizationSettings, UnsetType] = unset,
        subscription: Union[OrganizationSubscription, UnsetType] = unset,
        trial: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Create, edit, and manage organizations.

        :param billing: A JSON array of billing type. **Deprecated**.
        :type billing: OrganizationBilling, optional

        :param created: Date of the organization creation.
        :type created: str, optional

        :param description: Description of the organization.
        :type description: str, optional

        :param name: The name of the new child-organization, limited to 32 characters.
        :type name: str, optional

        :param public_id: The ``public_id`` of the organization you are operating within.
        :type public_id: str, optional

        :param settings: A JSON array of settings.
        :type settings: OrganizationSettings, optional

        :param subscription: Subscription definition. **Deprecated**.
        :type subscription: OrganizationSubscription, optional

        :param trial: Only available for MSP customers. Allows child organizations to be created on a trial plan.
        :type trial: bool, optional
        """
        if billing is not unset:
            kwargs["billing"] = billing
        if created is not unset:
            kwargs["created"] = created
        if description is not unset:
            kwargs["description"] = description
        if name is not unset:
            kwargs["name"] = name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if settings is not unset:
            kwargs["settings"] = settings
        if subscription is not unset:
            kwargs["subscription"] = subscription
        if trial is not unset:
            kwargs["trial"] = trial
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsTestProcessStatus(ModelSimple):
    """
    Status of a Synthetic test.

    :param value: Must be one of ["not_scheduled", "scheduled", "finished", "finished_with_error"].
    :type value: str
    """

    allowed_values = {
        "not_scheduled",
        "scheduled",
        "finished",
        "finished_with_error",
    }
    NOT_SCHEDULED: ClassVar["SyntheticsTestProcessStatus"]
    SCHEDULED: ClassVar["SyntheticsTestProcessStatus"]
    FINISHED: ClassVar["SyntheticsTestProcessStatus"]
    FINISHED_WITH_ERROR: ClassVar["SyntheticsTestProcessStatus"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsTestProcessStatus.NOT_SCHEDULED = SyntheticsTestProcessStatus("not_scheduled")
SyntheticsTestProcessStatus.SCHEDULED = SyntheticsTestProcessStatus("scheduled")
SyntheticsTestProcessStatus.FINISHED = SyntheticsTestProcessStatus("finished")
SyntheticsTestProcessStatus.FINISHED_WITH_ERROR = SyntheticsTestProcessStatus("finished_with_error")



"""
Create a pipeline returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.logs_pipelines_api import LogsPipelinesApi
from datadog_api_client.v1.model.logs_filter import LogsFilter
from datadog_api_client.v1.model.logs_grok_parser import LogsGrokParser
from datadog_api_client.v1.model.logs_grok_parser_rules import LogsGrokParserRules
from datadog_api_client.v1.model.logs_grok_parser_type import LogsGrokParserType
from datadog_api_client.v1.model.logs_pipeline import LogsPipeline

body = LogsPipeline(
    filter=LogsFilter(
        query="source:python",
    ),
    name="",
    processors=[
        LogsGrokParser(
            grok=LogsGrokParserRules(
                match_rules="rule_name_1 foo\nrule_name_2 bar\n",
                support_rules="rule_name_1 foo\nrule_name_2 bar\n",
            ),
            is_enabled=False,
            samples=[],
            source="message",
            type=LogsGrokParserType.GROK_PARSER,
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsPipelinesApi(api_client)
    response = api_instance.create_logs_pipeline(body=body)

    print(response)



"""
Get a list of events returns "OK" response with pagination
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.events_api import EventsApi

configuration = Configuration()
configuration.unstable_operations["list_events"] = True
with ApiClient(configuration) as api_client:
    api_instance = EventsApi(api_client)
    items = api_instance.list_events_with_pagination(
        filter_from="now-15m",
        filter_to="now",
        page_limit=2,
    )
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_arithmetic_processor_type import LogsArithmeticProcessorType


class LogsArithmeticProcessor(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_arithmetic_processor_type import LogsArithmeticProcessorType

        return {
            "expression": (str,),
            "is_enabled": (bool,),
            "is_replace_missing": (bool,),
            "name": (str,),
            "target": (str,),
            "type": (LogsArithmeticProcessorType,),
        }

    attribute_map = {
        "expression": "expression",
        "is_enabled": "is_enabled",
        "is_replace_missing": "is_replace_missing",
        "name": "name",
        "target": "target",
        "type": "type",
    }

    def __init__(
        self_,
        expression: str,
        target: str,
        type: LogsArithmeticProcessorType,
        is_enabled: Union[bool, UnsetType] = unset,
        is_replace_missing: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Use the Arithmetic Processor to add a new attribute (without spaces or special characters
        in the new attribute name) to a log with the result of the provided formula.
        This enables you to remap different time attributes with different units into a single attribute,
        or to compute operations on attributes within the same log.

        The formula can use parentheses and the basic arithmetic operators ``-`` , ``+`` , ``*`` , ``/``.

        By default, the calculation is skipped if an attribute is missing.
        Select “Replace missing attribute by 0” to automatically populate
        missing attribute values with 0 to ensure that the calculation is done.
        An attribute is missing if it is not found in the log attributes,
        or if it cannot be converted to a number.

        *Notes* :

        * The operator ``-`` needs to be space split in the formula as it can also be contained in attribute names.
        * If the target attribute already exists, it is overwritten by the result of the formula.
        * Results are rounded up to the 9th decimal. For example, if the result of the formula is ``0.1234567891`` ,
          the actual value stored for the attribute is ``0.123456789``.
        * If you need to scale a unit of measure,
          see `Scale Filter <https://docs.datadoghq.com/logs/log_configuration/parsing/?tab=filter#matcher-and-filter>`_.

        :param expression: Arithmetic operation between one or more log attributes.
        :type expression: str

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param is_replace_missing: If ``true`` , it replaces all missing attributes of expression by ``0`` , ``false``
            skip the operation if an attribute is missing.
        :type is_replace_missing: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param target: Name of the attribute that contains the result of the arithmetic operation.
        :type target: str

        :param type: Type of logs arithmetic processor.
        :type type: LogsArithmeticProcessorType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if is_replace_missing is not unset:
            kwargs["is_replace_missing"] = is_replace_missing
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.expression = expression
        self_.target = target
        self_.type = type



"""
Search tests events returns "OK" response with pagination
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.ci_visibility_tests_api import CIVisibilityTestsApi
from datadog_api_client.v2.model.ci_app_query_page_options import CIAppQueryPageOptions
from datadog_api_client.v2.model.ci_app_sort import CIAppSort
from datadog_api_client.v2.model.ci_app_test_events_request import CIAppTestEventsRequest
from datadog_api_client.v2.model.ci_app_tests_query_filter import CIAppTestsQueryFilter

body = CIAppTestEventsRequest(
    filter=CIAppTestsQueryFilter(
        _from="now-15m",
        query="@test.status:pass AND -@language:python",
        to="now",
    ),
    page=CIAppQueryPageOptions(
        limit=2,
    ),
    sort=CIAppSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = CIVisibilityTestsApi(api_client)
    items = api_instance.search_ci_app_test_events_with_pagination(body=body)
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ApplicationKeysSort(ModelSimple):
    """
    Sorting options

    :param value: If omitted defaults to "name". Must be one of ["created_at", "-created_at", "last4", "-last4", "name", "-name"].
    :type value: str
    """

    allowed_values = {
        "created_at",
        "-created_at",
        "last4",
        "-last4",
        "name",
        "-name",
    }
    CREATED_AT_ASCENDING: ClassVar["ApplicationKeysSort"]
    CREATED_AT_DESCENDING: ClassVar["ApplicationKeysSort"]
    LAST4_ASCENDING: ClassVar["ApplicationKeysSort"]
    LAST4_DESCENDING: ClassVar["ApplicationKeysSort"]
    NAME_ASCENDING: ClassVar["ApplicationKeysSort"]
    NAME_DESCENDING: ClassVar["ApplicationKeysSort"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ApplicationKeysSort.CREATED_AT_ASCENDING = ApplicationKeysSort("created_at")
ApplicationKeysSort.CREATED_AT_DESCENDING = ApplicationKeysSort("-created_at")
ApplicationKeysSort.LAST4_ASCENDING = ApplicationKeysSort("last4")
ApplicationKeysSort.LAST4_DESCENDING = ApplicationKeysSort("-last4")
ApplicationKeysSort.NAME_ASCENDING = ApplicationKeysSort("name")
ApplicationKeysSort.NAME_DESCENDING = ApplicationKeysSort("-name")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slo_creator import SLOCreator
    from datadog_api_client.v1.model.slo_overall_statuses import SLOOverallStatuses
    from datadog_api_client.v1.model.search_slo_query import SearchSLOQuery
    from datadog_api_client.v1.model.slo_type import SLOType
    from datadog_api_client.v1.model.search_slo_threshold import SearchSLOThreshold


class SearchServiceLevelObjectiveAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slo_creator import SLOCreator
        from datadog_api_client.v1.model.slo_overall_statuses import SLOOverallStatuses
        from datadog_api_client.v1.model.search_slo_query import SearchSLOQuery
        from datadog_api_client.v1.model.slo_type import SLOType
        from datadog_api_client.v1.model.search_slo_threshold import SearchSLOThreshold

        return {
            "all_tags": ([str],),
            "created_at": (int,),
            "creator": (SLOCreator,),
            "description": (str, none_type),
            "env_tags": ([str],),
            "groups": ([str], none_type),
            "modified_at": (int,),
            "monitor_ids": ([int], none_type),
            "name": (str,),
            "overall_status": ([SLOOverallStatuses],),
            "query": (SearchSLOQuery,),
            "service_tags": ([str],),
            "slo_type": (SLOType,),
            "team_tags": ([str],),
            "thresholds": ([SearchSLOThreshold],),
        }

    attribute_map = {
        "all_tags": "all_tags",
        "created_at": "created_at",
        "creator": "creator",
        "description": "description",
        "env_tags": "env_tags",
        "groups": "groups",
        "modified_at": "modified_at",
        "monitor_ids": "monitor_ids",
        "name": "name",
        "overall_status": "overall_status",
        "query": "query",
        "service_tags": "service_tags",
        "slo_type": "slo_type",
        "team_tags": "team_tags",
        "thresholds": "thresholds",
    }
    read_only_vars = {
        "created_at",
        "modified_at",
    }

    def __init__(
        self_,
        all_tags: Union[List[str], UnsetType] = unset,
        created_at: Union[int, UnsetType] = unset,
        creator: Union[SLOCreator, none_type, UnsetType] = unset,
        description: Union[str, none_type, UnsetType] = unset,
        env_tags: Union[List[str], UnsetType] = unset,
        groups: Union[List[str], none_type, UnsetType] = unset,
        modified_at: Union[int, UnsetType] = unset,
        monitor_ids: Union[List[int], none_type, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        overall_status: Union[List[SLOOverallStatuses], UnsetType] = unset,
        query: Union[SearchSLOQuery, none_type, UnsetType] = unset,
        service_tags: Union[List[str], UnsetType] = unset,
        slo_type: Union[SLOType, UnsetType] = unset,
        team_tags: Union[List[str], UnsetType] = unset,
        thresholds: Union[List[SearchSLOThreshold], UnsetType] = unset,
        **kwargs,
    ):
        """
        A service level objective object includes a service level indicator, thresholds
        for one or more timeframes, and metadata ( ``name`` , ``description`` , and ``tags`` ).

        :param all_tags: A list of tags associated with this service level objective.
            Always included in service level objective responses (but may be empty).
        :type all_tags: [str], optional

        :param created_at: Creation timestamp (UNIX time in seconds)

            Always included in service level objective responses.
        :type created_at: int, optional

        :param creator: The creator of the SLO
        :type creator: SLOCreator, none_type, optional

        :param description: A user-defined description of the service level objective.

            Always included in service level objective responses (but may be ``null`` ).
            Optional in create/update requests.
        :type description: str, none_type, optional

        :param env_tags: Tags with the ``env`` tag key.
        :type env_tags: [str], optional

        :param groups: A list of (up to 100) monitor groups that narrow the scope of a monitor service level objective.
            Included in service level objective responses if it is not empty.
        :type groups: [str], none_type, optional

        :param modified_at: Modification timestamp (UNIX time in seconds)

            Always included in service level objective responses.
        :type modified_at: int, optional

        :param monitor_ids: A list of monitor ids that defines the scope of a monitor service level
            objective.
        :type monitor_ids: [int], none_type, optional

        :param name: The name of the service level objective object.
        :type name: str, optional

        :param overall_status: calculated status and error budget remaining.
        :type overall_status: [SLOOverallStatuses], optional

        :param query: A metric-based SLO. **Required if type is metric**. Note that Datadog only allows the sum by aggregator
            to be used because this will sum up all request counts instead of averaging them, or taking the max or
            min of all of those requests.
        :type query: SearchSLOQuery, none_type, optional

        :param service_tags: Tags with the ``service`` tag key.
        :type service_tags: [str], optional

        :param slo_type: The type of the service level objective.
        :type slo_type: SLOType, optional

        :param team_tags: Tags with the ``team`` tag key.
        :type team_tags: [str], optional

        :param thresholds: The thresholds (timeframes and associated targets) for this service level
            objective object.
        :type thresholds: [SearchSLOThreshold], optional
        """
        if all_tags is not unset:
            kwargs["all_tags"] = all_tags
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if creator is not unset:
            kwargs["creator"] = creator
        if description is not unset:
            kwargs["description"] = description
        if env_tags is not unset:
            kwargs["env_tags"] = env_tags
        if groups is not unset:
            kwargs["groups"] = groups
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if monitor_ids is not unset:
            kwargs["monitor_ids"] = monitor_ids
        if name is not unset:
            kwargs["name"] = name
        if overall_status is not unset:
            kwargs["overall_status"] = overall_status
        if query is not unset:
            kwargs["query"] = query
        if service_tags is not unset:
            kwargs["service_tags"] = service_tags
        if slo_type is not unset:
            kwargs["slo_type"] = slo_type
        if team_tags is not unset:
            kwargs["team_tags"] = team_tags
        if thresholds is not unset:
            kwargs["thresholds"] = thresholds
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class MonitorOptionsSchedulingOptionsEvaluationWindow(ModelNormal):
    validations = {
        "hour_starts": {
            "inclusive_maximum": 59,
            "inclusive_minimum": 0,
        },
        "month_starts": {
            "inclusive_maximum": 1,
            "inclusive_minimum": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "day_starts": (str,),
            "hour_starts": (int,),
            "month_starts": (int,),
        }

    attribute_map = {
        "day_starts": "day_starts",
        "hour_starts": "hour_starts",
        "month_starts": "month_starts",
    }

    def __init__(
        self_,
        day_starts: Union[str, UnsetType] = unset,
        hour_starts: Union[int, UnsetType] = unset,
        month_starts: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Configuration options for the evaluation window. If ``hour_starts`` is set, no other fields may be set. Otherwise, ``day_starts`` and ``month_starts`` must be set together.

        :param day_starts: The time of the day at which a one day cumulative evaluation window starts. Must be defined in UTC time in ``HH:mm`` format.
        :type day_starts: str, optional

        :param hour_starts: The minute of the hour at which a one hour cumulative evaluation window starts.
        :type hour_starts: int, optional

        :param month_starts: The day of the month at which a one month cumulative evaluation window starts.
        :type month_starts: int, optional
        """
        if day_starts is not unset:
            kwargs["day_starts"] = day_starts
        if hour_starts is not unset:
            kwargs["hour_starts"] = hour_starts
        if month_starts is not unset:
            kwargs["month_starts"] = month_starts
        super().__init__(kwargs)
